@@ -1,7 +1,10 @@
-// mouse wheel
-pref("mousewheel.withcontrolkey.action", 1);
+// mouse wheel: disable mozilla's ctrl+wheel zooming
+// bug: setting this to -1 does not disable the built-in action, but instead
+// prevents event delivery at all!
+pref("mousewheel.withcontrolkey.action", 0);
 pref("mousewheel.withcontrolkey.numlines", 1);
 pref("mousewheel.withcontrolkey.sysnumlines", false);
+
 // fix horizontal scroll with 2nd wheel, see bug #148557
 pref("mousewheel.horizscroll.withnokey.action", 0);
 pref("mousewheel.horizscroll.withnokey.sysnumlines", true);
@@ -39,6 +42,7 @@ pref("security.warn_entering_secure", false);
 pref("security.warn_entering_secure.show_once", true);
 pref("security.warn_leaving_secure", false);
 pref("security.warn_submit_insecure", false);
+pref("security.warn_submit_insecure.show_once", false);
 
 // fonts
 pref("font.size.unit", "pt");
@@ -57,6 +61,15 @@ pref("font.size.fixed.th", 10);
 pref("font.size.fixed.zh-TW", 10);
 pref("font.size.fixed.zh-HK", 10);
 pref("font.size.fixed.tr", 10);
+pref("font.size.fixed.x-armn", 10);
+pref("font.size.fixed.x-beng", 10);
+pref("font.size.fixed.x-cans", 10);
+pref("font.size.fixed.x-ethi", 10);
+pref("font.size.fixed.x-geor", 10);
+pref("font.size.fixed.x-gujr", 10);
+pref("font.size.fixed.x-guru", 10);
+pref("font.size.fixed.x-khmr", 10);
+pref("font.size.fixed.x-mlym", 10);
 pref("font.size.fixed.x-unicode", 10);
 pref("font.size.fixed.x-western", 10);
 pref("font.size.variable.ar", 11);
@@ -74,6 +87,15 @@ pref("font.size.variable.th", 11);
 pref("font.size.variable.zh-TW", 11);
 pref("font.size.variable.zh-HK", 11);
 pref("font.size.variable.tr", 11);
+pref("font.size.variable.x-armn", 11);
+pref("font.size.variable.x-beng", 11);
+pref("font.size.variable.x-cans", 11);
+pref("font.size.variable.x-ethi", 11);
+pref("font.size.variable.x-geor", 11);
+pref("font.size.variable.x-gujr", 11);
+pref("font.size.variable.x-guru", 11);
+pref("font.size.variable.x-khmr", 11);
+pref("font.size.variable.x-mlym", 11);
 pref("font.size.variable.x-unicode", 11);
 pref("font.size.variable.x-western", 11);
 
@@ -87,5 +109,4 @@ pref("network.protocol-handler.external.webcal", true);
 pref("xpinstall.enabled", false);
 
 // enable typeahead find
-pref("accessibility.typeaheadfind", true);
-
+pref("accessibility.typeaheadfind", false);
