@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed.c,v 1.58 2005/01/30 15:20:35 chpe Exp $
+ *  $Id: ephy-embed.c,v 1.63 2005/06/03 13:42:33 chpe Exp $
  */
 
 #include "config.h"
@@ -92,8 +92,8 @@ ephy_embed_base_init (gpointer g_class)
 			      ephy_marshal_VOID__STRING_STRING,
 			      G_TYPE_NONE,
 			      2,
-			      G_TYPE_STRING,
-			      G_TYPE_STRING);
+			      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE,
+			      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE);
 /**
  * EphyEmbed::ge-context-menu:
  * @embed:
@@ -128,7 +128,28 @@ ephy_embed_base_init (gpointer g_class)
 			      g_cclosure_marshal_VOID__STRING,
 			      G_TYPE_NONE,
 			      1,
-			      G_TYPE_STRING);
+			      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE);
+/**
+ * EphyEmbed::ge-feed-link:
+ * @embed:
+ * @type: the mime-type of the news feed
+ * @title: the title of the news feed
+ * @address: the URL to @embed's web site's news feed
+ *
+ * The ::ge_rss signal is emitted when @embed discovers that a news feed
+ * is available for the site it is visiting.
+ **/
+		g_signal_new ("ge_feed_link",
+			      EPHY_TYPE_EMBED,
+			      G_SIGNAL_RUN_FIRST,
+			      G_STRUCT_OFFSET (EphyEmbedIface, feed_link),
+			      NULL, NULL,
+			      ephy_marshal_VOID__STRING_STRING_STRING,
+			      G_TYPE_NONE,
+			      3,
+			      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE,
+			      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE,
+			      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE);
 /**
  * EphyEmbed::ge-location:
  * @embed:
@@ -149,7 +170,7 @@ ephy_embed_base_init (gpointer g_class)
 			      g_cclosure_marshal_VOID__STRING,
 			      G_TYPE_NONE,
 			      1,
-			      G_TYPE_STRING);
+			      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE);
 /**
  * EphyEmbed::ge-net-state:
  * @embed:
@@ -168,7 +189,7 @@ ephy_embed_base_init (gpointer g_class)
 			      ephy_marshal_VOID__STRING_FLAGS,
 			      G_TYPE_NONE,
 			      2,
-			      G_TYPE_STRING,
+			      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE,
 			      EPHY_TYPE_EMBED_NET_STATE);
 /**
  * EphyEmbed::ge-dom-mouse-click:
@@ -260,7 +281,7 @@ ephy_embed_base_init (gpointer g_class)
 			      g_cclosure_marshal_VOID__STRING,
 			      G_TYPE_NONE,
 			      1,
-			      G_TYPE_STRING);
+			      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE);
 
 /**
  * EphyEmbed::ge-modal-alert:
@@ -311,6 +332,41 @@ ephy_embed_base_init (gpointer g_class)
 			      G_TYPE_NONE,
 			      1,
 			      EPHY_TYPE_EMBED_DOCUMENT_TYPE);
+/**
+ * EphyEmbed::dom-content-loaded:
+ * @embed:
+ *
+ * The ::dom-content-loaded signal is emitted when 
+ * the document has been loaded (excluding images and other loads initiated by this document).
+ * That's true also for frameset and all the frames within it.
+ **/
+		g_signal_new ("dom_content_loaded",
+			      EPHY_TYPE_EMBED,
+			      G_SIGNAL_RUN_FIRST,
+			      G_STRUCT_OFFSET (EphyEmbedIface, dom_content_loaded),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__POINTER,
+			      G_TYPE_NONE,
+			      1,
+			      G_TYPE_POINTER);
+
+/**
+ * EphyEmbed::ge-search-key-press:
+ * @embed:
+ * @event: the #GdkEventKey which triggered this signal
+ *
+ * The ::ge-search-key-press signal is emitted for keypresses which
+ * should be used for find implementations.
+ **/
+		g_signal_new ("ge-search-key-press",
+			      EPHY_TYPE_EMBED,
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (EphyEmbedIface, context_menu),
+			      g_signal_accumulator_true_handled, NULL,
+			      ephy_marshal_BOOLEAN__BOXED,
+			      G_TYPE_BOOLEAN,
+			      1,
+			      GDK_TYPE_EVENT | G_SIGNAL_TYPE_STATIC_SCOPE);
 
 		initialized = TRUE;
 	}
@@ -675,43 +731,6 @@ ephy_embed_show_page_certificate (EphyEmbed *embed)
 	iface->show_page_certificate (embed);
 }
 
-/**
- * ephy_embed_find_set_properties:
- * @embed: an #EphyEmbed
- * @search_string: the desired search string
- * @case_sensitive: %TRUE for "case sensitive" to be set
- * @wrap_around: %TRUE for "wrap around" to be set
- *
- * Sets the properties of @embed's "Find" dialog.
- **/
-void
-ephy_embed_find_set_properties  (EphyEmbed *embed,
-				 const char *search_string,
-				 gboolean case_sensitive,
-				 gboolean wrap_around)
-{
-	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	iface->find_set_properties (embed, search_string, case_sensitive,
-				    wrap_around);
-}
-
-/**
- * ephy_embed_find_next:
- * @embed: an #EphyEmbed
- * @backwards: %FALSE to search forwards in the document
- *
- * Equivalent to pressing "Next" in @embed's Find dialog.
- *
- * Return value: %TRUE if a next match was found
- **/
-gboolean
-ephy_embed_find_next (EphyEmbed *embed,
-		      gboolean backwards)
-{
-	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	return iface->find_next (embed, backwards);
-}
-
 /**
  * ephy_embed_activate:
  * @embed: an #EphyEmbed
