@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ContentHandler.cpp,v 1.77.2.5 2005/06/16 12:38:29 chpe Exp $
+ *  $Id: ContentHandler.cpp,v 1.82 2005/05/25 22:08:01 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -43,6 +43,7 @@
 #include <nsIMIMEInfo.h>
 #include <nsIInterfaceRequestorUtils.h>
 #include <nsCExternalHandlerService.h>
+#include <nsIDOMWindow.h>
 #include <nsNetError.h>
 
 #ifdef ALLOW_PRIVATE_API
@@ -322,7 +323,7 @@ NS_METHOD GContentHandler::MIMEConfirmAction ()
 	button = gtk_button_new_with_label (_("_Save As..."));
 	image = gtk_image_new_from_stock (GTK_STOCK_SAVE_AS, GTK_ICON_SIZE_BUTTON);
 	gtk_button_set_image (GTK_BUTTON (button), image);
-	/* don't show the image! see bug #307818 */
+	gtk_widget_show (image);
 	gtk_widget_show (button);
 	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, CONTENT_ACTION_SAVEAS);
 
