@@ -1,5 +1,6 @@
 /*
  *  Copyright (C) 2000-2004 Marco Pesenti Gritti
+ *  Copyright (C) 2003, 2004, 2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.cpp,v 1.76.2.1 2005/04/07 11:46:32 chpe Exp $
+ *  $Id: EphyBrowser.cpp,v 1.89 2005/05/31 15:27:17 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -27,6 +28,7 @@
 #include "EventContext.h"
 #include "ephy-embed.h"
 #include "ephy-string.h"
+#include "ephy-zoom.h"
 #include "ephy-debug.h"
 #include "print-dialog.h"
 #include "mozilla-embed.h"
@@ -40,7 +42,6 @@
 #include "nsISimpleEnumerator.h"
 
 #include "nsIContentViewer.h"
-#include "nsIWebBrowserFind.h"
 #include "nsIWebBrowserFocus.h"
 #include "nsICommandManager.h"
 #include "nsIWebBrowserPrint.h"
@@ -99,58 +100,39 @@
 #endif
 #endif
 
-static PRUnichar DOMLinkAdded[] = { 'D', 'O', 'M', 'L', 'i', 'n', 'k',
-				    'A', 'd', 'd', 'e', 'd', '\0' };
-static PRUnichar ContextMenu[] = { 'c', 'o', 'n', 't', 'e', 'x', 't', 'm',
-				   'e', 'n', 'u', '\0' };
-static PRUnichar DOMPopupBlocked[] = { 'D', 'O', 'M', 'P', 'o', 'p',
-				       'u', 'p', 'B', 'l', 'o', 'c',
-				       'k', 'e', 'd', '\0' };
-static PRUnichar DOMWillOpenModalDialog[] = { 'D', 'O', 'M', 'W', 'i', 'l', 'l',
-					      'O', 'p', 'e', 'n', 'M', 'o', 'd',
-					      'a', 'l', 'D', 'i', 'a', 'l', 'o',
-					      'g', '\0' };
-static PRUnichar DOMModalDialogClosed[] = { 'D', 'O', 'M', 'M', 'o', 'd', 'a',
-					    'l', 'D', 'i', 'a', 'l', 'o', 'g',
-					    'C', 'l', 'o', 's', 'e', 'd', '\0' };
-
-EphyEventListener::EphyEventListener()
-: mOwner(nsnull)
-{
-	LOG ("EphyEventListener ctor (%p)", this);
-}
-
-EphyEventListener::~EphyEventListener()
-{
-	LOG ("EphyEventListener dtor (%p)", this);
-}
+const static PRUnichar kDOMLinkAdded[]		 = { 'D', 'O', 'M', 'L', 'i', 'n', 'k', 'A', 'd', 'd', 'e', 'd', '\0' };
+const static PRUnichar kDOMContentLoaded[]	 = { 'D', 'O', 'M', 'C', 'o', 'n', 't', 'e', 'n', 't', 'L', 'o', 'a', 'd', 'e', 'd', '\0' };
+const static PRUnichar kContextMenu[]		 = { 'c', 'o', 'n', 't', 'e', 'x', 't', 'm', 'e', 'n', 'u', '\0' };
+const static PRUnichar kDOMMouseScroll[]	 = { 'D', 'O', 'M', 'M', 'o', 'u', 's', 'e', 'S', 'c', 'r', 'o', 'l', 'l', '\0' };
+const static PRUnichar kDOMPopupBlocked[]	 = { 'D', 'O', 'M', 'P', 'o', 'p', 'u', 'p', 'B', 'l', 'o', 'c', 'k', 'e', 'd', '\0' };
+const static PRUnichar kDOMWillOpenModalDialog[] = { 'D', 'O', 'M', 'W', 'i', 'l', 'l', 'O', 'p', 'e', 'n', 'M', 'o', 'd', 'a', 'l', 'D', 'i', 'a', 'l', 'o', 'g', '\0' };
+const static PRUnichar kDOMModalDialogClosed[]	 = { 'D', 'O', 'M', 'M', 'o', 'd', 'a', 'l', 'D', 'i', 'a', 'l', 'o', 'g', 'C', 'l', 'o', 's', 'e', 'd', '\0' };
+const static PRUnichar kHrefAttr[]		 = { 'h', 'r', 'e', 'f', '\0' };
+const static PRUnichar kTypeAttr[]		 = { 't', 'y', 'p', 'e', '\0' };
+const static PRUnichar kTitleAttr[]		 = { 't', 'i', 't', 'l', 'e', '\0' };
+const static PRUnichar kRelAttr[]		 = { 'r', 'e', 'l', '\0' };
 
 NS_IMPL_ISUPPORTS1(EphyEventListener, nsIDOMEventListener)
 
-nsresult
-EphyEventListener::Init (EphyBrowser *aOwner)
-{
-	mOwner = aOwner;
-	return NS_OK;
-}
-
 NS_IMETHODIMP
-EphyFaviconEventListener::HandleEvent(nsIDOMEvent* aDOMEvent)
+EphyDOMLinkEventListener::HandleEvent (nsIDOMEvent* aDOMEvent)
 {
+	/* make sure the event is trusted */
+	nsCOMPtr<nsIDOMNSEvent> nsEvent (do_QueryInterface (aDOMEvent));
+	NS_ENSURE_TRUE (nsEvent, NS_ERROR_FAILURE);
+	PRBool isTrusted = PR_FALSE;
+	nsEvent->GetIsTrusted (&isTrusted);
+	if (!isTrusted) return NS_OK;
+
 	nsCOMPtr<nsIDOMEventTarget> eventTarget;
 	aDOMEvent->GetTarget(getter_AddRefs(eventTarget));
 
-	nsCOMPtr<nsIDOMNode> node = do_QueryInterface(eventTarget);
-	NS_ENSURE_TRUE (node, NS_ERROR_FAILURE);
-
-	nsCOMPtr<nsIDOMElement> linkElement;
-	linkElement = do_QueryInterface (node);
+	nsCOMPtr<nsIDOMElement> linkElement (do_QueryInterface (eventTarget));
 	if (!linkElement) return NS_ERROR_FAILURE;
 
-	PRUnichar relAttr[] = { 'r', 'e', 'l', '\0' };
 	nsresult rv;
 	nsEmbedString value;
-	rv = linkElement->GetAttribute (nsEmbedString(relAttr), value);
+	rv = linkElement->GetAttribute (nsEmbedString(kRelAttr), value);
 	if (NS_FAILED (rv)) return NS_ERROR_FAILURE;
 
 	nsEmbedCString rel;
@@ -159,16 +141,8 @@ EphyFaviconEventListener::HandleEvent(nsIDOMEvent* aDOMEvent)
 	if (g_ascii_strcasecmp (rel.get(), "SHORTCUT ICON") == 0 ||
 	    g_ascii_strcasecmp (rel.get(), "ICON") == 0)
 	{
-		PRUnichar hrefAttr[] = { 'h', 'r', 'e', 'f', '\0' };
-		nsEmbedString hrefValue;
-		rv = linkElement->GetAttribute (nsEmbedString (hrefAttr), hrefValue);
-		if (NS_FAILED (rv) || !hrefValue.Length()) return NS_ERROR_FAILURE;
-
-		nsEmbedCString link;
-		NS_UTF16ToCString (hrefValue, NS_CSTRING_ENCODING_UTF8, link);
-
 		nsCOMPtr<nsIDOMDocument> domDoc;
-		node->GetOwnerDocument(getter_AddRefs(domDoc));
+		linkElement->GetOwnerDocument(getter_AddRefs(domDoc));
 		NS_ENSURE_TRUE (domDoc, NS_ERROR_FAILURE);
 
 		nsCOMPtr<nsIDOMDocumentView> docView (do_QueryInterface (domDoc));
@@ -188,22 +162,18 @@ EphyFaviconEventListener::HandleEvent(nsIDOMEvent* aDOMEvent)
 		/* disallow subframes to set favicon */
 		if (domWinAsISupports != topDomWinAsISupports) return NS_OK;
 
-		nsCOMPtr<nsIDOM3Document> doc (do_QueryInterface (domDoc));
-		NS_ENSURE_TRUE (doc, NS_ERROR_FAILURE);
-
-		nsEmbedString spec;
-		rv = doc->GetDocumentURI (spec);
-		NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
-
-                nsEmbedCString encoding;
-                mOwner->GetEncoding (encoding);
-
 		nsCOMPtr<nsIURI> docUri;
-		EphyUtils::NewURI (getter_AddRefs(docUri), spec, encoding.get());
-		NS_ENSURE_TRUE (docUri, NS_ERROR_FAILURE);
+		rv = GetDocURI (linkElement, getter_AddRefs (docUri));
+		NS_ENSURE_TRUE (NS_SUCCEEDED (rv) && docUri, NS_ERROR_FAILURE);
+
+		rv = linkElement->GetAttribute (nsEmbedString (kHrefAttr), value);
+		if (NS_FAILED (rv) || !value.Length()) return NS_ERROR_FAILURE;
+
+		nsEmbedCString cLink;
+		NS_UTF16ToCString (value, NS_CSTRING_ENCODING_UTF8, cLink);
 
 		nsEmbedCString faviconUrl;
-		rv = docUri->Resolve (link, faviconUrl);
+		rv = docUri->Resolve (cLink, faviconUrl);
 		NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
 		nsCOMPtr<nsIURI> favUri;
@@ -228,15 +198,10 @@ EphyFaviconEventListener::HandleEvent(nsIDOMEvent* aDOMEvent)
 		NS_ENSURE_TRUE (policy, NS_OK);
 
 #if MOZ_NSICONTENTPOLICY_VARIANT == 2
-		/* FIXME: mozilla tabbrowser.xml passes
-		 * safeGetProperty(event.target, "type") as mimetype guess:
-		 */
-		PRUnichar typeAttr[] = { 't', 'y', 'p', 'e', '\0' };
-		nsEmbedString typeVal;
-		linkElement->GetAttribute (nsEmbedString (typeAttr), typeVal);
+		linkElement->GetAttribute (nsEmbedString (kTypeAttr), value);
 
 		nsEmbedCString cTypeVal;
-		NS_UTF16ToCString (typeVal, NS_CSTRING_ENCODING_UTF8, cTypeVal);
+		NS_UTF16ToCString (value, NS_CSTRING_ENCODING_UTF8, cTypeVal);
 
 		PRInt16 decision = 0;
 		rv = policy->ShouldLoad (nsIContentPolicy::TYPE_IMAGE,
@@ -254,17 +219,107 @@ EphyFaviconEventListener::HandleEvent(nsIDOMEvent* aDOMEvent)
 		NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 		if (!shouldLoad) return NS_OK;
 #endif
+		
+		/* Hide password part */
+		nsEmbedCString user;
+		favUri->GetUsername (user);
+		favUri->SetUserPass (user);
+
+		nsEmbedCString spec;
+		favUri->GetSpec (spec);
 
 		/* ok, we accept this as a valid favicon for this site */
-		g_signal_emit_by_name (mOwner->mEmbed, "ge_favicon", faviconUrl.get());
+		g_signal_emit_by_name (mOwner->mEmbed, "ge_favicon", spec.get());
+	}
+	else if (g_ascii_strcasecmp (rel.get (), "alternate") == 0)
+	{
+		linkElement->GetAttribute (nsEmbedString (kTypeAttr), value);
+
+		nsEmbedCString cTypeVal;
+		NS_UTF16ToCString (value, NS_CSTRING_ENCODING_UTF8, cTypeVal);
+
+		if (g_ascii_strcasecmp (cTypeVal.get (), "application/rss+xml") == 0 ||
+		    g_ascii_strcasecmp (cTypeVal.get (), "application/atom+xml") == 0)
+		{
+			rv = linkElement->GetAttribute (nsEmbedString (kHrefAttr), value);
+			if (NS_FAILED (rv) || !value.Length()) return NS_ERROR_FAILURE;
+
+			nsEmbedCString cLink;
+			NS_UTF16ToCString (value, NS_CSTRING_ENCODING_UTF8, cLink);
+
+			nsCOMPtr<nsIURI> docUri;
+			rv = GetDocURI (linkElement, getter_AddRefs (docUri));
+			NS_ENSURE_TRUE (NS_SUCCEEDED (rv) && docUri, NS_ERROR_FAILURE);
+
+			/* Hide password part */
+			docUri->SetPassword (nsEmbedCString ());
+
+			nsEmbedCString resolvedLink;
+			rv = docUri->Resolve (cLink, resolvedLink);
+			NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
+
+			linkElement->GetAttribute (nsEmbedString (kTitleAttr), value);
+
+			nsEmbedCString cTitle;
+			NS_UTF16ToCString (value, NS_CSTRING_ENCODING_UTF8, cTitle);
+
+			g_signal_emit_by_name (mOwner->mEmbed, "ge_feed_link",
+					       cTypeVal.get(), cTitle.get(), resolvedLink.get());
+		}
 	}
 
 	return NS_OK;
 }
 
+NS_IMETHODIMP
+EphyDOMContentLoadedEventListener::HandleEvent (nsIDOMEvent* aDOMEvent)
+{
+	LOG ("DOMContentLoaded event fired up");
+
+	/* make sure the event is trusted */
+	nsCOMPtr<nsIDOMNSEvent> nsEvent (do_QueryInterface (aDOMEvent));
+	NS_ENSURE_TRUE (nsEvent, NS_ERROR_FAILURE);
+	PRBool isTrusted = PR_FALSE;
+	nsEvent->GetIsTrusted (&isTrusted);
+	if (!isTrusted) return NS_OK;
+
+	g_signal_emit_by_name (mOwner->mEmbed, "dom_content_loaded", (gpointer)aDOMEvent);
+
+	return NS_OK;
+}
+
+nsresult
+EphyDOMLinkEventListener::GetDocURI (nsIDOMElement *aElement,
+				     nsIURI **aDocURI)
+{
+	nsCOMPtr<nsIDOMDocument> domDoc;
+	aElement->GetOwnerDocument (getter_AddRefs(domDoc));
+
+	nsCOMPtr<nsIDOM3Document> doc (do_QueryInterface (domDoc));
+	NS_ENSURE_TRUE (doc, NS_ERROR_FAILURE);
+
+	nsresult rv;
+	nsEmbedString spec;
+	rv = doc->GetDocumentURI (spec);
+	NS_ENSURE_SUCCESS (rv, rv);
+
+	nsEmbedCString encoding;
+	rv = mOwner->GetEncoding (encoding);
+	NS_ENSURE_SUCCESS (rv, rv);
+
+	return EphyUtils::NewURI (aDocURI, spec, encoding.get());
+}
+
 NS_IMETHODIMP
 EphyPopupBlockEventListener::HandleEvent (nsIDOMEvent * aDOMEvent)
 {
+	/* make sure the event is trusted */
+	nsCOMPtr<nsIDOMNSEvent> nsEvent (do_QueryInterface (aDOMEvent));
+	NS_ENSURE_TRUE (nsEvent, NS_ERROR_FAILURE);
+	PRBool isTrusted = PR_FALSE;
+	nsEvent->GetIsTrusted (&isTrusted);
+	if (!isTrusted) return NS_OK;
+
 	nsCOMPtr<nsIDOMPopupBlockedEvent> popupEvent =
 		do_QueryInterface (aDOMEvent);
 	NS_ENSURE_TRUE (popupEvent, NS_ERROR_FAILURE);
@@ -297,7 +352,6 @@ EphyPopupBlockEventListener::HandleEvent (nsIDOMEvent * aDOMEvent)
 NS_IMETHODIMP
 EphyModalAlertEventListener::HandleEvent (nsIDOMEvent * aDOMEvent)
 {
-#ifdef MOZ_NSIDOMNSEVENT_GETISTRUSTED
 	NS_ENSURE_TRUE (mOwner, NS_ERROR_FAILURE);
 
 	/* make sure the event is trusted */
@@ -333,31 +387,55 @@ EphyModalAlertEventListener::HandleEvent (nsIDOMEvent * aDOMEvent)
 	{
 		g_signal_emit_by_name (mOwner->mEmbed, "ge-modal-alert-closed");
 	}
-#endif
 
 	return NS_OK;
 }
 
-EphyContextMenuListener::EphyContextMenuListener()
-: mOwner(nsnull)
+NS_IMETHODIMP
+EphyDOMScrollEventListener::HandleEvent (nsIDOMEvent * aEvent)
 {
-	LOG ("EphyContextMenuListener ctor (%p)", this);
-}
+	/* make sure the event is trusted */
+	nsresult rv;
+	nsCOMPtr<nsIDOMNSEvent> nsEvent (do_QueryInterface (aEvent, &rv));
+	NS_ENSURE_SUCCESS (rv, rv);
+	PRBool isTrusted = PR_FALSE;
+	nsEvent->GetIsTrusted (&isTrusted);
+	if (!isTrusted) return NS_OK;
 
-EphyContextMenuListener::~EphyContextMenuListener()
-{
-	LOG ("EphyContextMenuListener dtor (%p)", this);
+	nsCOMPtr<nsIDOMMouseEvent> mouseEvent (do_QueryInterface (aEvent, &rv));
+	NS_ENSURE_SUCCESS (rv, rv);
+		
+	PRBool isAlt = PR_FALSE, isControl = PR_FALSE, isShift = PR_FALSE;
+	mouseEvent->GetAltKey (&isAlt);
+	mouseEvent->GetCtrlKey (&isControl);
+	mouseEvent->GetShiftKey (&isShift);
+	/* GetMetaKey is always false on gtk2 mozilla */
+
+	if (isControl && !isAlt && !isShift)
+	{
+		PRInt32 detail = 0;
+		mouseEvent->GetDetail(&detail);
+
+		float zoom;
+		rv = mOwner->GetZoom (&zoom);
+		NS_ENSURE_SUCCESS (rv, rv);
+
+		zoom = ephy_zoom_get_changed_zoom_level (zoom, detail > 0 ? 1 : detail < 0 ? -1 : 0);
+		rv = mOwner->SetZoom (zoom);
+		if (NS_SUCCEEDED (rv))
+		{
+			g_signal_emit_by_name (mOwner->mEmbed, "ge_zoom_change", zoom);
+		}
+
+		/* we consumed the event */
+		aEvent->PreventDefault();	 
+	}
+	 
+	return NS_OK;
 }
 
 NS_IMPL_ISUPPORTS1(EphyContextMenuListener, nsIDOMContextMenuListener)
 
-nsresult
-EphyContextMenuListener::Init(EphyBrowser *aOwner)
-{
-	mOwner = aOwner;
-	return NS_OK;
-}
-
 NS_IMETHODIMP
 EphyContextMenuListener::ContextMenu (nsIDOMEvent* aDOMEvent)
 {
@@ -432,7 +510,9 @@ EphyContextMenuListener::HandleEvent (nsIDOMEvent* aDOMEvent)
 }
 
 EphyBrowser::EphyBrowser ()
-: mFaviconEventListener(nsnull)
+: mDOMLinkEventListener(nsnull)
+, mDOMContentLoadedEventListener(nsnull)
+, mDOMScrollEventListener(nsnull)
 , mPopupBlockEventListener(nsnull)
 , mModalAlertListener(nsnull)
 , mContextMenuListener(nsnull)
@@ -465,30 +545,24 @@ nsresult EphyBrowser::Init (GtkMozEmbed *mozembed)
 	rv = mDOMWindow->GetDocument (getter_AddRefs (domDocument));
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
-	mFaviconEventListener = new EphyFaviconEventListener();
-	if (!mFaviconEventListener) return NS_ERROR_OUT_OF_MEMORY;
+	mDOMLinkEventListener = new EphyDOMLinkEventListener(this);
+	if (!mDOMLinkEventListener) return NS_ERROR_OUT_OF_MEMORY;
 
-	rv = mFaviconEventListener->Init (this);
-	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
+	mDOMContentLoadedEventListener = new EphyDOMContentLoadedEventListener(this);
+	if (!mDOMContentLoadedEventListener) return NS_ERROR_OUT_OF_MEMORY;
 
-	mPopupBlockEventListener = new EphyPopupBlockEventListener();
+	mDOMScrollEventListener = new EphyDOMScrollEventListener(this);
+	if (!mDOMScrollEventListener) return NS_ERROR_OUT_OF_MEMORY;
+
+	mPopupBlockEventListener = new EphyPopupBlockEventListener(this);
 	if (!mPopupBlockEventListener) return NS_ERROR_OUT_OF_MEMORY;
 
-	rv = mPopupBlockEventListener->Init (this);
-	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
-
-	mModalAlertListener = new EphyModalAlertEventListener ();
+	mModalAlertListener = new EphyModalAlertEventListener (this);
 	if (!mModalAlertListener) return NS_ERROR_OUT_OF_MEMORY;
 
-	rv = mModalAlertListener->Init (this);
-	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
-
-	mContextMenuListener = new EphyContextMenuListener();
+	mContextMenuListener = new EphyContextMenuListener(this);
 	if (!mContextMenuListener) return NS_ERROR_OUT_OF_MEMORY;
 
-	rv = mContextMenuListener->Init (this);
-	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
-
  	rv = GetListener();
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
@@ -496,6 +570,13 @@ nsresult EphyBrowser::Init (GtkMozEmbed *mozembed)
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
 #ifdef HAVE_MOZILLA_PSM
+#ifdef HAVE_GECKO_1_8
+	nsCOMPtr<nsIDocShell> docShell (do_GetInterface (mWebBrowser, &rv));
+	NS_ENSURE_SUCCESS (rv, rv);
+
+	rv = docShell->GetSecurityUI (getter_AddRefs (mSecurityInfo));
+	NS_ENSURE_SUCCESS (rv, rv);
+#else
 	/* FIXME: mozilla sucks! nsWebBrowser already has an instance of this,
 	 * but we cannot get to it!
 	 * See https://bugzilla.mozilla.org/show_bug.cgi?id=94974
@@ -532,11 +613,12 @@ nsresult EphyBrowser::Init (GtkMozEmbed *mozembed)
 			NS_ENSURE_SUCCESS (rv, rv);
 		}
 	}
+#endif /* HAVE_GECKO_1_8 */
 	if (!mSecurityInfo)
 	{
-		g_warning ("Failed to instantiate nsISecureBrowserUI!\n");
+		g_warning ("Failed to get nsISecureBrowserUI!\n");
  	}
-#endif
+#endif /* HAVE_MOZILLA_PSM */
 
 	mInitialized = PR_TRUE;
 
@@ -566,15 +648,21 @@ EphyBrowser::AttachListeners(void)
 	NS_ENSURE_TRUE (mEventTarget, NS_ERROR_FAILURE);
 
 	nsresult rv;
-	rv = mEventTarget->AddEventListener(nsEmbedString(DOMLinkAdded),
-					    mFaviconEventListener, PR_FALSE);
-	rv |= mEventTarget->AddEventListener(nsEmbedString(DOMPopupBlocked),
+	rv = mEventTarget->AddEventListener(nsEmbedString(kDOMLinkAdded),
+					    mDOMLinkEventListener, PR_FALSE);
+	rv |= mEventTarget->AddEventListener(nsEmbedString(kDOMContentLoaded),
+					     mDOMContentLoadedEventListener, PR_FALSE);
+	rv |= mEventTarget->AddEventListener(nsEmbedString(kDOMMouseScroll),
+					     mDOMScrollEventListener, PR_TRUE); /* capture */
+	rv |= mEventTarget->AddEventListener(nsEmbedString(kDOMPopupBlocked),
 					     mPopupBlockEventListener, PR_FALSE);
-	rv |= mEventTarget->AddEventListener(nsEmbedString(DOMWillOpenModalDialog),
+	rv |= mEventTarget->AddEventListener(nsEmbedString(kDOMWillOpenModalDialog),
 					     mModalAlertListener, PR_TRUE);
-	rv |= mEventTarget->AddEventListener(nsEmbedString(DOMModalDialogClosed),
+	rv |= mEventTarget->AddEventListener(nsEmbedString(kDOMMouseScroll),
+					     mDOMScrollEventListener, PR_TRUE);
+	rv |= mEventTarget->AddEventListener(nsEmbedString(kDOMModalDialogClosed),
 					     mModalAlertListener, PR_TRUE);
-	rv |= mEventTarget->AddEventListener(nsEmbedString(ContextMenu),
+	rv |= mEventTarget->AddEventListener(nsEmbedString(kContextMenu),
 					     mContextMenuListener, PR_TRUE /* capture */);
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
@@ -587,15 +675,19 @@ EphyBrowser::DetachListeners(void)
 	if (!mEventTarget) return NS_OK;
 
 	nsresult rv;
-	rv = mEventTarget->RemoveEventListener(nsEmbedString(DOMLinkAdded),
-					       mFaviconEventListener, PR_FALSE);
-	rv |= mEventTarget->RemoveEventListener(nsEmbedString(DOMPopupBlocked),
+	rv = mEventTarget->RemoveEventListener(nsEmbedString(kDOMLinkAdded),
+					       mDOMLinkEventListener, PR_FALSE);
+	rv |= mEventTarget->RemoveEventListener(nsEmbedString(kDOMContentLoaded),
+					        mDOMContentLoadedEventListener, PR_FALSE);
+	rv |= mEventTarget->RemoveEventListener(nsEmbedString(kDOMMouseScroll),
+						mDOMScrollEventListener, PR_TRUE); /* capture */
+	rv |= mEventTarget->RemoveEventListener(nsEmbedString(kDOMPopupBlocked),
 					        mPopupBlockEventListener, PR_FALSE);
-	rv |= mEventTarget->RemoveEventListener(nsEmbedString(DOMWillOpenModalDialog),
+	rv |= mEventTarget->RemoveEventListener(nsEmbedString(kDOMWillOpenModalDialog),
 						mModalAlertListener, PR_TRUE);
-	rv |= mEventTarget->RemoveEventListener(nsEmbedString(DOMModalDialogClosed),
+	rv |= mEventTarget->RemoveEventListener(nsEmbedString(kDOMModalDialogClosed),
 						mModalAlertListener, PR_TRUE);
-	rv |= mEventTarget->RemoveEventListener(nsEmbedString(ContextMenu),
+	rv |= mEventTarget->RemoveEventListener(nsEmbedString(kContextMenu),
 					        mContextMenuListener, PR_TRUE /* capture */);
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
@@ -711,7 +803,7 @@ nsresult EphyBrowser::GoToHistoryIndex (PRInt16 index)
 	return ContentNav->GotoIndex (index);
 }
 
-#ifdef GTKMOZEMBED_BROKEN_RELOAD
+#ifndef HAVE_GECKO_1_8
 /* Workaround for broken reload with frames, see mozilla bug
  * http://bugzilla.mozilla.org/show_bug.cgi?id=246392
  */
@@ -749,7 +841,7 @@ nsresult EphyBrowser::Reload (ReloadType flags)
 
 	return webNavigation->Reload (reloadFlags);
 }
-#endif
+#endif /* !HAVE_GECKO_1_8 */
 
 nsresult EphyBrowser::SetZoom (float aZoom)
 {
@@ -883,35 +975,6 @@ nsresult EphyBrowser::GetSHUrlAtIndex (PRInt32 index, nsACString &url)
 	return NS_OK;
 }
 
-nsresult EphyBrowser::FindSetProperties (const PRUnichar *search_string,
-			                 PRBool case_sensitive,
-					 PRBool wrap_around)
-{
-	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
-
-	nsCOMPtr<nsIWebBrowserFind> finder (do_GetInterface(mWebBrowser));
-	NS_ENSURE_TRUE (finder, NS_ERROR_FAILURE);
-
-	finder->SetSearchString (search_string);
-	finder->SetMatchCase (case_sensitive);
-	finder->SetWrapFind (wrap_around);
-
-	return NS_OK;
-}
-
-nsresult EphyBrowser::Find (PRBool backwards,
-			    PRBool *didFind)
-{
-	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
-
-	nsCOMPtr<nsIWebBrowserFind> finder (do_GetInterface(mWebBrowser));
-	NS_ENSURE_TRUE (finder, NS_ERROR_FAILURE);
-
-	finder->SetFindBackwards (backwards);
-
-	return finder->FindNext(didFind);
-}
-
 nsresult EphyBrowser::GetPageDescriptor(nsISupports **aPageDescriptor)
 {
 	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
@@ -936,48 +999,38 @@ nsresult EphyBrowser::GetDOMWindow (nsIDOMWindow **aDOMWindow)
 	return NS_OK;
 }
 
-nsresult EphyBrowser::GetDocumentUrl (nsACString &url)
+nsresult EphyBrowser::GetDocumentURI (nsIURI **aURI)
 {
+	if (!mDOMWindow) return NS_ERROR_NOT_INITIALIZED;
+
 	nsresult rv;
-
-	NS_ENSURE_TRUE (mDOMWindow, NS_ERROR_FAILURE);
-
-	nsCOMPtr<nsIDOMDocument> DOMDocument;
-	mDOMWindow->GetDocument (getter_AddRefs(DOMDocument));
-	NS_ENSURE_TRUE (DOMDocument, NS_ERROR_FAILURE);
-
-	nsCOMPtr<nsIDOM3Document> doc = do_QueryInterface(DOMDocument);
-	NS_ENSURE_TRUE (doc, NS_ERROR_FAILURE);
-
-	nsEmbedString docURI;
-	rv = doc->GetDocumentURI (docURI);
+	nsCOMPtr<nsIWebNavigation> webNav (do_GetInterface (mDOMWindow, &rv));
 	NS_ENSURE_SUCCESS (rv, rv);
 
-	NS_UTF16ToCString (docURI, NS_CSTRING_ENCODING_UTF8, url);
-
-	return NS_OK;
+	return webNav->GetCurrentURI (aURI);
 }
 
-nsresult EphyBrowser::GetTargetDocumentUrl (nsACString &url)
+nsresult EphyBrowser::GetTargetDocumentURI (nsIURI **aURI)
 {
+	if (!mWebBrowser) return NS_ERROR_NOT_INITIALIZED;
+
+        nsCOMPtr<nsIDOMDocument> domDoc;
+	GetTargetDocument (getter_AddRefs(domDoc));
+	NS_ENSURE_TRUE (domDoc, NS_ERROR_FAILURE);
+
+	nsCOMPtr<nsIDOMDocumentView> docView (do_QueryInterface (domDoc));
+	NS_ENSURE_TRUE (docView, NS_ERROR_FAILURE);
+
+	nsCOMPtr<nsIDOMAbstractView> abstractView;
+	docView->GetDefaultView (getter_AddRefs (abstractView));
+	NS_ENSURE_TRUE (abstractView, NS_ERROR_FAILURE);
+	/* the abstract view is really the DOM window */
+
 	nsresult rv;
-
-	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
-
-        nsCOMPtr<nsIDOMDocument> DOMDocument;
-	GetTargetDocument (getter_AddRefs(DOMDocument));
-	NS_ENSURE_TRUE (DOMDocument, NS_ERROR_FAILURE);
-
-	nsCOMPtr<nsIDOM3Document> doc = do_QueryInterface(DOMDocument);
-	NS_ENSURE_TRUE (doc, NS_ERROR_FAILURE);
-
-	nsEmbedString docURI;
-	rv = doc->GetDocumentURI (docURI);
+	nsCOMPtr<nsIWebNavigation> webNav (do_GetInterface (abstractView, &rv));
 	NS_ENSURE_SUCCESS (rv, rv);
 
-	NS_UTF16ToCString (docURI, NS_CSTRING_ENCODING_UTF8, url);
-
-	return NS_OK;
+	return webNav->GetCurrentURI (aURI);
 }
 
 nsresult EphyBrowser::ForceEncoding (const char *encoding) 
