@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EventContext.cpp,v 1.50 2005/02/27 14:13:45 chpe Exp $
+ *  $Id: EventContext.cpp,v 1.58 2005/06/03 16:47:46 jframeau Exp $
  */
 
 #include "mozilla-config.h"
@@ -26,14 +26,16 @@
 
 #include "EventContext.h"
 #include "EphyUtils.h"
+#include "ephy-debug.h"
 
 #include <gdk/gdkkeysyms.h>
 
 #include <nsIInterfaceRequestor.h>
+#include <nsIInterfaceRequestorUtils.h>
 #include <nsIServiceManager.h>
-#define MOZILLA_STRICT_API
+#undef MOZILLA_INTERNAL_API
 #include <nsEmbedString.h>
-#undef MOZILLA_STRICT_API
+#define MOZILLA_INTERNAL_API 1
 #include <nsIDOMEventTarget.h>
 #include <nsIDOMHTMLInputElement.h>
 #include <nsIDOMHTMLObjectElement.h>
@@ -41,9 +43,11 @@
 #include <nsIDOMElement.h>
 #include <nsIURI.h>
 #include <nsIDOMCharacterData.h>
+#include <nsIDOMHTMLAreaElement.h>
 #include <nsIDOMHTMLButtonElement.h>
 #include <nsIDOMHTMLLabelElement.h>
 #include <nsIDOMHTMLLegendElement.h>
+#include <nsIDOMHTMLMapElement.h>
 #include <nsIDOMHTMLTextAreaElement.h>
 #include <nsIDOMElementCSSInlineStyle.h>
 #include <nsIDOMCSSStyleDeclaration.h>
@@ -52,6 +56,8 @@
 #include <nsIDOMNodeList.h>
 #include <nsIDOMDocumentView.h>
 #include <nsIDOMAbstractView.h>
+#include <nsIDOMNSHTMLDocument.h>
+#include <nsIDOMNSUIEvent.h>
 
 #ifdef ALLOW_PRIVATE_API
 #include <nsITextToSubURI.h>
@@ -65,10 +71,12 @@
 
 EventContext::EventContext ()
 {
+	LOG ("EventContext ctor [%p]", this);
 }
 
 EventContext::~EventContext ()
 {
+	LOG ("EventContext dtor [%p]", this);
 }
 
 nsresult EventContext::Init (EphyBrowser *browser)
@@ -157,22 +165,13 @@ nsresult EventContext::GatherTextUnder (nsIDOMNode* aNode, nsAString& aResult)
 	return NS_OK;
 }
 
+/* FIXME: we should resolve against the element's base, not the document's base */
 nsresult EventContext::ResolveBaseURL (const nsAString &relurl, nsACString &url)
 {
-	nsresult rv;
-
-	nsCOMPtr<nsIDOM3Node> node(do_QueryInterface (mDOMDocument));
-	nsEmbedString spec;
-	node->GetBaseURI (spec);
-
-	nsCOMPtr<nsIURI> base;
-	rv = EphyUtils::NewURI (getter_AddRefs(base), spec);
-	if (!base) return NS_ERROR_FAILURE;
-
 	nsEmbedCString cRelURL;
 	NS_UTF16ToCString (relurl, NS_CSTRING_ENCODING_UTF8, cRelURL);	
 
-	return base->Resolve (cRelURL, url);
+	return mBaseURI->Resolve (cRelURL, url);
 }
 
 nsresult EventContext::Unescape (const nsACString &aEscaped, nsACString &aUnescaped)
@@ -203,6 +202,7 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 	nsresult rv;
 
 	const PRUnichar hrefLiteral[] = {'h', 'r', 'e', 'f', '\0'};
+	const PRUnichar imgLiteral[] = {'i', 'm', 'g', '\0'};
 	const PRUnichar typeLiteral[] = {'t', 'y', 'p', 'e', '\0'};
 	const PRUnichar xlinknsLiteral[] = {'h', 't', 't', 'p', ':', '/', '/','w',
 				            'w', 'w', '.', 'w', '3', '.', 'o', 'r',
@@ -227,8 +227,6 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 	rv = node->GetOwnerDocument(getter_AddRefs(domDoc));
 	if (NS_FAILED(rv) || !domDoc) return NS_ERROR_FAILURE;
 
-	mDOMDocument = domDoc;
-
 	nsCOMPtr<nsIDOMXULDocument> xul_document = do_QueryInterface(domDoc);
 	if (xul_document)
 	{
@@ -236,6 +234,29 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 		return NS_ERROR_FAILURE;
 	}
 
+	mDOMDocument = domDoc;
+
+	rv = mBrowser->GetEncoding (mCharset);
+	NS_ENSURE_SUCCESS (rv, rv);
+
+	/* Get base URI and CSS view */
+	nsCOMPtr<nsIDOMDocumentView> docView (do_QueryInterface (domDoc));
+	NS_ENSURE_TRUE (docView, NS_ERROR_FAILURE);
+
+	nsCOMPtr<nsIDOMAbstractView> abstractView;
+	docView->GetDefaultView (getter_AddRefs (abstractView));
+	NS_ENSURE_TRUE (abstractView, NS_ERROR_FAILURE);
+	/* the abstract view is really the DOM window */
+
+	mViewCSS = do_QueryInterface (abstractView);
+	NS_ENSURE_TRUE (mViewCSS, NS_ERROR_FAILURE);
+
+	nsCOMPtr<nsIWebNavigation> webNav (do_GetInterface (abstractView, &rv));
+	NS_ENSURE_SUCCESS (rv, rv);
+
+	rv = webNav->GetCurrentURI (getter_AddRefs (mBaseURI));
+	NS_ENSURE_SUCCESS (rv, rv);
+
 	// Now we know that the page isn't a xul window, we can try and
 	// do something useful with it.
 
@@ -268,6 +289,66 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 			if (NS_FAILED(rv)) return NS_ERROR_FAILURE;
 			SetStringProperty ("image", img);
 		}
+		else if (g_ascii_strcasecmp (tag.get(), "area") == 0)
+		{
+			nsCOMPtr <nsIDOMHTMLAreaElement> area = 
+						do_QueryInterface(node, &rv);
+			if (NS_FAILED(rv) || !area) return NS_ERROR_FAILURE;			
+
+			// Parent node is the map itself
+			nsCOMPtr<nsIDOMNode> parentNode;
+			node->GetParentNode (getter_AddRefs(parentNode));
+
+			nsCOMPtr <nsIDOMHTMLMapElement> map = 
+				do_QueryInterface(parentNode, &rv);
+			if (NS_FAILED(rv) || !area) return NS_ERROR_FAILURE;			
+
+			nsEmbedString mapName;
+			rv = map->GetName (mapName);
+			if (NS_FAILED(rv)) return NS_ERROR_FAILURE;
+
+			// Now we are searching for all the images with a usemap attribute
+			nsCOMPtr<nsIDOMNodeList> imgs;
+			rv = mDOMDocument->GetElementsByTagName (nsEmbedString(imgLiteral), 	
+								 getter_AddRefs (imgs));
+			if (NS_FAILED(rv)) return NS_ERROR_FAILURE;
+			
+			PRUint32 imgs_count;
+			rv = imgs->GetLength (&imgs_count);
+			if (NS_FAILED (rv)) return NS_ERROR_FAILURE;
+
+			for (PRUint32 i = 0; i < imgs_count; i++)
+			{
+				nsCOMPtr<nsIDOMNode> aNode;
+				rv = imgs->Item (i, getter_AddRefs (aNode));
+				if (NS_FAILED (rv)) continue;
+
+				nsCOMPtr<nsIDOMHTMLImageElement> img = 
+						do_QueryInterface(aNode, &rv);
+				if (NS_FAILED(rv) || !img) continue;
+			
+				nsEmbedString imgMapName;
+				rv = img->GetUseMap (imgMapName);
+				if (NS_FAILED (rv)) continue;
+
+				// usemap always starts with #
+				imgMapName.Cut (0,1);
+
+				// Check if the current image is attached to the map we are looking for
+				if (EphyUtils::StringEquals(imgMapName, mapName))
+				{
+					nsEmbedString imgSrc;
+					rv = img->GetSrc (imgSrc);
+					if (NS_FAILED(rv)) continue;
+
+					info->context |= EPHY_EMBED_CONTEXT_IMAGE;
+
+					SetStringProperty ("image", imgSrc);
+
+					break;
+				}
+			}
+		}
 		else if (g_ascii_strcasecmp (tag.get(), "input") == 0)
 		{
 			CheckInput (node);
@@ -365,7 +446,7 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 				dom_elem->GetAttributeNS (nsEmbedString(xlinknsLiteral),
 							  nsEmbedString(hrefLiteral), value);
 				
-				SetStringProperty ("link", value);
+				SetURIProperty (node, "link", value);
 				CheckLinkScheme (value);
 			}
 		}
@@ -421,7 +502,7 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 				{
 					info->context |= EPHY_EMBED_CONTEXT_LINK;
 
-					SetStringProperty ("link", tmp);
+					SetURIProperty (node, "link", tmp);
 					CheckLinkScheme (tmp);
 					rv = anchor->GetHreflang (tmp);
 					if (NS_SUCCEEDED(rv))
@@ -491,7 +572,7 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 					if (NS_FAILED(rv))
 						return NS_ERROR_FAILURE;
 					
-					SetStringProperty ("link", href);
+					SetURIProperty (node, "link", href);
 					CheckLinkScheme (href);
 				}
 			}
@@ -533,6 +614,8 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 
 nsresult EventContext::GetCSSBackground (nsIDOMNode *node, nsAString& url)
 {
+	if (!mViewCSS) return NS_ERROR_NOT_INITIALIZED;
+
 	nsresult rv;
 
 	const PRUnichar bgimage[] = {'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd',
@@ -541,18 +624,9 @@ nsresult EventContext::GetCSSBackground (nsIDOMNode *node, nsAString& url)
 	nsCOMPtr<nsIDOMElement> element = do_QueryInterface (node);
 	NS_ENSURE_TRUE (element, NS_ERROR_FAILURE);
 
-	nsCOMPtr<nsIDOMDocumentView> docView = do_QueryInterface (mDOMDocument);
-	NS_ENSURE_TRUE (docView, NS_ERROR_FAILURE);
-
-	nsCOMPtr<nsIDOMAbstractView> abstractView;
-	docView->GetDefaultView (getter_AddRefs (abstractView));
-
-	nsCOMPtr<nsIDOMViewCSS> viewCSS = do_QueryInterface (abstractView);
-	NS_ENSURE_TRUE (viewCSS, NS_ERROR_FAILURE);
-
 	nsCOMPtr<nsIDOMCSSStyleDeclaration> decl;
-	viewCSS->GetComputedStyle (element, nsEmbedString(),
-				   getter_AddRefs (decl));
+	mViewCSS->GetComputedStyle (element, nsEmbedString(),
+				    getter_AddRefs (decl));
 	NS_ENSURE_TRUE (decl, NS_ERROR_FAILURE);
 
 	nsCOMPtr<nsIDOMCSSValue> CSSValue;
@@ -619,11 +693,13 @@ nsresult EventContext::GetMouseEventInfo (nsIDOMMouseEvent *aMouseEvent, Mozilla
 			info->button = 3;
 			break;
 
-#ifdef MOZ_BROKEN_CTX_MENU_EVENT
+#ifndef HAVE_GECKO_1_8
 		case 1729:
 			/* This only appears to happen when getting a mouse context menu
 			 * signal, so map it to button 3 (right mouse button)
-			 * http://bugzilla.mozilla.org/show_bug.cgi?id=258193 */
+			 * http://bugzilla.mozilla.org/show_bug.cgi?id=258193 
+			 * Fixed since 1.8a4
+			 */
 			info->button = 3;
 			break;
 #endif
@@ -656,6 +732,13 @@ nsresult EventContext::GetMouseEventInfo (nsIDOMMouseEvent *aMouseEvent, Mozilla
 	nsCOMPtr<nsIDOMNSEvent> nsEvent = do_QueryInterface(aMouseEvent);
 	if (!nsEvent) return NS_ERROR_FAILURE;
 
+#ifdef MOZ_NSIDOMNSEVENT_GETISTRUSTED
+	/* make sure the event is trusted */
+	PRBool isTrusted = PR_FALSE;
+	nsEvent->GetIsTrusted (&isTrusted);
+	if (!isTrusted) return NS_ERROR_UNEXPECTED;
+#endif /* MOZ_NSIDOMNSEVENT_GETISTRUSTED */
+
 	nsresult rv;
 	nsCOMPtr<nsIDOMEventTarget> OriginalTarget;
 	rv = nsEvent->GetOriginalTarget(getter_AddRefs(OriginalTarget));
@@ -707,6 +790,17 @@ nsresult EventContext::GetMouseEventInfo (nsIDOMMouseEvent *aMouseEvent, Mozilla
 
 nsresult EventContext::GetKeyEventInfo (nsIDOMKeyEvent *aKeyEvent, MozillaEmbedEvent *info)
 {
+#ifdef MOZ_NSIDOMNSEVENT_GETISTRUSTED
+	/* make sure the event is trusted */
+	nsCOMPtr<nsIDOMNSEvent> nsEvent (do_QueryInterface (aKeyEvent));
+	NS_ENSURE_TRUE (nsEvent, NS_ERROR_FAILURE);
+
+	PRBool isTrusted = PR_FALSE;
+	nsEvent->GetIsTrusted (&isTrusted);
+	if (!isTrusted) return NS_ERROR_UNEXPECTED;
+#endif /* MOZ_NSIDOMNSEVENT_GETISTRUSTED */
+
+
 	info->button = 0;
 
 	nsresult rv;
@@ -882,3 +976,100 @@ nsresult EventContext::SetStringProperty (const char *name, const nsAString &val
 	NS_UTF16ToCString (value, NS_CSTRING_ENCODING_UTF8, cValue);
 	return SetStringProperty (name, cValue.get());
 }
+
+nsresult EventContext::SetURIProperty (nsIDOMNode *node, const char *name, const nsACString &value)
+{
+	nsresult rv;
+	nsCOMPtr<nsIURI> uri;
+	rv = EphyUtils::NewURI (getter_AddRefs (uri), value, mCharset.Length () ? mCharset.get() : nsnull, mBaseURI);
+	if (NS_SUCCEEDED (rv) && uri)
+	{
+		/* Hide password part */
+		nsEmbedCString user;
+		uri->GetUsername (user);
+		uri->SetUserPass (user);
+
+		nsEmbedCString spec;
+		uri->GetSpec (spec);
+		rv = SetStringProperty (name, spec.get());
+	}
+	else
+	{
+		rv = SetStringProperty (name, nsEmbedCString(value).get());
+	}
+
+	return rv;
+}
+
+nsresult EventContext::SetURIProperty (nsIDOMNode *node, const char *name, const nsAString &value)
+{
+	nsEmbedCString cValue;
+	NS_UTF16ToCString (value, NS_CSTRING_ENCODING_UTF8, cValue);
+	return SetURIProperty (node, name, cValue);
+}
+
+/* static */
+PRBool
+EventContext::CheckKeyPress (nsIDOMKeyEvent *aEvent)
+{
+	PRBool retval = PR_FALSE;
+
+	/* check for alt/ctrl */
+	PRBool isCtrl = PR_FALSE, isAlt = PR_FALSE;
+	aEvent->GetCtrlKey (&isCtrl);
+	aEvent->GetAltKey (&isAlt);
+	if (isCtrl || isAlt) return retval;
+
+	nsCOMPtr<nsIDOMNSUIEvent> uiEvent (do_QueryInterface (aEvent));
+	NS_ENSURE_TRUE (uiEvent, retval);
+
+	/* check for already handled event */
+	PRBool isPrevented = PR_FALSE;
+	uiEvent->GetPreventDefault (&isPrevented);
+	if (isPrevented) return retval;
+
+	/* check for form controls */
+	nsresult rv;
+	nsCOMPtr<nsIDOMEventTarget> target;
+	rv = aEvent->GetTarget (getter_AddRefs (target));
+	NS_ENSURE_SUCCESS (rv, retval);
+
+	nsCOMPtr<nsIDOMHTMLElement> element (do_QueryInterface (target, &rv));
+	NS_ENSURE_SUCCESS (rv, retval);
+
+	PRUint16 type = 0;
+	element->GetNodeType(&type);
+	if (nsIDOMNode::ELEMENT_NODE != type) return retval;
+
+	nsEmbedString uTag;
+	rv = element->GetLocalName(uTag);
+	NS_ENSURE_SUCCESS (rv, retval);
+
+	nsEmbedCString tag;
+	NS_UTF16ToCString (uTag, NS_CSTRING_ENCODING_UTF8, tag);
+
+	if (g_ascii_strcasecmp (tag.get(), "input") == 0 ||
+	    g_ascii_strcasecmp (tag.get(), "textarea") == 0 ||
+	    g_ascii_strcasecmp (tag.get(), "select") == 0 ||
+	    g_ascii_strcasecmp (tag.get(), "button") == 0 ||
+	    g_ascii_strcasecmp (tag.get(), "isindex") == 0) return retval;
+
+	/* check for design mode */
+	nsCOMPtr<nsIDOMDocument> doc;
+	rv = element->GetOwnerDocument (getter_AddRefs (doc));
+	NS_ENSURE_SUCCESS (rv, retval);
+
+	nsCOMPtr<nsIDOMNSHTMLDocument> htmlDoc (do_QueryInterface (doc, &rv));
+	if (NS_FAILED (rv)) return retval; /* it's okay not to be a HTML document */
+
+	nsEmbedString uDesign;
+	rv = htmlDoc->GetDesignMode (uDesign);
+	NS_ENSURE_SUCCESS (rv, retval);
+
+	nsEmbedCString design;
+	NS_UTF16ToCString (uDesign, NS_CSTRING_ENCODING_UTF8, design);
+
+	retval = g_ascii_strcasecmp (design.get(), "on") != 0;
+
+	return retval;
+}
