@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id$
+ *  $Id: mozilla-embed.cpp,v 1.106 2005/06/03 13:42:34 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -64,6 +64,9 @@ static gboolean mozilla_embed_dom_mouse_click_cb(GtkMozEmbed *embed,
 static gboolean mozilla_embed_dom_mouse_down_cb	(GtkMozEmbed *embed,
 						 gpointer dom_event, 
 						 MozillaEmbed *membed);
+static gboolean mozilla_embed_dom_key_press_cb	(GtkMozEmbed *embed,
+						 gpointer dom_event, 
+						 MozillaEmbed *membed);
 static void mozilla_embed_new_window_cb		(GtkMozEmbed *embed, 
 						 GtkMozEmbed **newEmbed,
 						 guint chrome_mask,
@@ -88,20 +91,12 @@ struct MozillaEmbedPrivate
 {
 	EphyBrowser *browser;
 	MozillaEmbedLoadState load_state;
-#ifdef GTKMOZEMBED_BROKEN_FOCUS
-	guint focus_connected : 1;
-#endif /* GTKMOZEMBED_BROKEN_FOCUS */
 };
 
 #define WINDOWWATCHER_CONTRACTID "@mozilla.org/embedcomp/window-watcher;1"
 
 static GObjectClass *parent_class = NULL;
 
-#ifdef GTKMOZEMBED_BROKEN_FOCUS
-static guint fiesid = 0;
-static guint foesid = 0;
-#endif /* GTKMOZEMBED_BROKEN_FOCUS */
-
 static void
 impl_manager_do_command (EphyCommandManager *manager,
 			 const char *command) 
@@ -180,141 +175,32 @@ mozilla_embed_get_type (void)
         return type;
 }
 
-static gboolean
-impl_find_next (EphyEmbed *embed, 
-                gboolean backwards)
-{
-	MozillaEmbedPrivate *mpriv = MOZILLA_EMBED(embed)->priv;
-	nsresult rv;
-        PRBool didFind;
-
-        rv = mpriv->browser->Find (backwards, &didFind);
-	
-	return NS_SUCCEEDED (rv) ? didFind : FALSE;
-}
-
 static void
 impl_activate (EphyEmbed *embed) 
 {
 	gtk_widget_grab_focus (GTK_BIN (embed)->child);
 }
 
-static void
-impl_find_set_properties (EphyEmbed *embed, 
-                          const char *search_string,
-	                  gboolean case_sensitive,
-			  gboolean wrap_around)
-{
-	MozillaEmbedPrivate *mpriv = MOZILLA_EMBED(embed)->priv;
-
-	nsEmbedString searchString;
-	NS_CStringToUTF16 (nsEmbedCString(search_string),
-			   NS_CSTRING_ENCODING_UTF8, searchString);
-
-	mpriv->browser->FindSetProperties (searchString.get(), case_sensitive,
-					   wrap_around); 
-}
-
-#ifdef GTKMOZEMBED_BROKEN_FOCUS
-static gboolean
-child_focus_in_event_cb (GtkWidget *child,
-			 GdkEventFocus *event,
-			 MozillaEmbed *embed)
-{
-	embed->priv->browser->FocusActivate ();
-
-	return FALSE;
-}
-
-static gboolean
-child_focus_out_event_cb (GtkWidget *child,
-			  GdkEventFocus *event,
-			  MozillaEmbed *embed)
-{
-	embed->priv->browser->FocusDeactivate ();
-
-	return FALSE;
-}
-#endif /* GTKMOZEMBED_BROKEN_FOCUS */
-
 static void
 mozilla_embed_realize (GtkWidget *widget)
 {
 	MozillaEmbedPrivate *mpriv = MOZILLA_EMBED (widget)->priv;
-	GtkBin *bin = GTK_BIN (widget);
 
-	GTK_WIDGET_CLASS (parent_class)->realize (widget);
+	(* GTK_WIDGET_CLASS(parent_class)->realize) (widget);
 
-	/* Initialise our helper class */
 	nsresult rv;
 	rv = mpriv->browser->Init (GTK_MOZ_EMBED (widget));
+
 	if (NS_FAILED (rv))
 	{
-		g_warning ("EphyBrowser initialization failed for %p\n", widget);
-		return;
+               	g_warning ("EphyBrowser initialization failed for %p\n", widget);
 	}
-
-#ifdef GTKMOZEMBED_BROKEN_FOCUS
-	/* HACK ALERT! This depends highly on undocumented interna of
-	 * GtkMozEmbed!
-	 *
-	 * GtkMozEmbed::realize installs focus-[in|out]-event handlers to
-	 * toplevel, and, on the first realize only, to the child.
-	 * GtkMozEmbed disconnects its focus-[in|out]-event handler
-	 * to the toplevel on unrealize, and leaves the ones to the child
-	 * in place. So we don't need to unblock the blocked handlers
-	 * and therefore need no ::unrealize handler.
-	*/
-
-	GtkWidget *toplevel = gtk_widget_get_toplevel (widget);
-	gpointer data = ((GtkMozEmbed *) widget)->data;
-
-	guint n;
-
-	n = g_signal_handlers_block_matched (toplevel,
-					     (GSignalMatchType) (G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_DATA),
-					     fiesid, 0, NULL, NULL, data);
-	n += g_signal_handlers_block_matched (toplevel,
-					      (GSignalMatchType) (G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_DATA),
-					      foesid, 0, NULL, NULL, data);
-	if (n != 2)
-	{
-		g_warning ("Unexpected number (n=%d) of toplevel focus handlers found!\n", n);
-	}
-
-	if (mpriv->focus_connected) return;
-
-	GtkWidget *child = gtk_bin_get_child (GTK_BIN (widget));
-	g_return_if_fail (child != NULL);
-
-	n = g_signal_handlers_block_matched (child,
-					     (GSignalMatchType) (G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_DATA),
-					     fiesid, 0, NULL, NULL, widget);
-	n += g_signal_handlers_block_matched (child,
-					      (GSignalMatchType) (G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_DATA),
-					      foesid, 0, NULL, NULL, widget);
-	if (n != 2)
-	{
-		g_warning ("Unexpected number (n=%d) of child focus handlers found!\n", n);
-	}
-
-	g_signal_connect_object (child, "focus-in-event",
-				 G_CALLBACK (child_focus_in_event_cb), widget,
-				 G_CONNECT_AFTER);
-	g_signal_connect_object (child, "focus-out-event",
-				 G_CALLBACK (child_focus_out_event_cb), widget,
-				 G_CONNECT_AFTER);
-
-	mpriv->focus_connected = TRUE;
-#endif /* GTKMOZEMBED_BROKEN_FOCUS */
 }
 
 static GObject *
 mozilla_embed_constructor (GType type, guint n_construct_properties,
 			   GObjectConstructParam *construct_params)
 {
-	g_object_ref (embed_shell);
-
 	/* we depend on single because of mozilla initialization */
 	ephy_embed_shell_get_embed_single (embed_shell);
 
@@ -338,11 +224,6 @@ mozilla_embed_class_init (MozillaEmbedClass *klass)
 
 	widget_class->realize = mozilla_embed_realize;
 
-#ifdef GTKMOZEMBED_BROKEN_FOCUS
-	fiesid = g_signal_lookup ("focus-in-event", GTK_TYPE_WIDGET);
-	foesid = g_signal_lookup ("focus-out-event", GTK_TYPE_WIDGET);
-#endif /* GTKMOZEMBED_BROKEN_FOCUS */
-
 	g_type_class_add_private (object_class, sizeof(MozillaEmbedPrivate));
 }
 
@@ -364,6 +245,9 @@ mozilla_embed_init (MozillaEmbed *embed)
 	g_signal_connect_object (G_OBJECT (embed), "dom_mouse_down",
 				 G_CALLBACK (mozilla_embed_dom_mouse_down_cb),
 				 embed, (GConnectFlags) 0);
+	g_signal_connect_object (G_OBJECT (embed), "dom-key-press",
+				 G_CALLBACK (mozilla_embed_dom_key_press_cb),
+				 embed, (GConnectFlags) 0);
 	g_signal_connect_object (G_OBJECT (embed), "new_window",
 				 G_CALLBACK (mozilla_embed_new_window_cb),
 				 embed, (GConnectFlags) 0);
@@ -405,8 +289,6 @@ mozilla_embed_finalize (GObject *object)
 	}
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
-
-	g_object_unref (embed_shell);
 }
 
 static void
@@ -604,7 +486,10 @@ static void
 impl_reload (EphyEmbed *embed, 
              gboolean force)
 {
-	guint32 mflags = GTK_MOZ_EMBED_FLAG_RELOADNORMAL;
+#ifdef HAVE_GECKO_1_8
+	guint32 mflags;
+
+	mflags = GTK_MOZ_EMBED_FLAG_RELOADNORMAL;
 
 	if (force)
 	{
@@ -612,6 +497,15 @@ impl_reload (EphyEmbed *embed,
 	}
 
 	gtk_moz_embed_reload (GTK_MOZ_EMBED(embed), mflags);
+#else
+	/* Workaround for broken reload with frames, see mozilla bug
+	 * http://bugzilla.mozilla.org/show_bug.cgi?id=246392
+	 */
+	MozillaEmbedPrivate *mpriv = MOZILLA_EMBED (embed)->priv;
+
+	mpriv->browser->Reload (force ? EphyBrowser::RELOAD_FORCE :
+					EphyBrowser::RELOAD_NORMAL);
+#endif
 }
 
 static void
@@ -807,8 +701,15 @@ impl_set_encoding (EphyEmbed *embed,
 		if (NS_FAILED (rv)) return;
 	}
 
+#ifdef HAVE_GECKO_1_8
 	gtk_moz_embed_reload (GTK_MOZ_EMBED (embed),
 			      GTK_MOZ_EMBED_FLAG_RELOADCHARSETCHANGE);
+#else
+	/* Workaround for broken reload with frames, see mozilla bug
+	 * http://bugzilla.mozilla.org/show_bug.cgi?id=246392
+	 */
+	mpriv->browser->Reload (EphyBrowser::RELOAD_ENCODING_CHANGE);
+#endif
 }
 
 static char *
@@ -1015,6 +916,33 @@ mozilla_embed_dom_mouse_down_cb (GtkMozEmbed *embed, gpointer dom_event,
 						"ge_dom_mouse_down");
 }
 
+static gint
+mozilla_embed_dom_key_press_cb (GtkMozEmbed *embed,
+				gpointer dom_event, 
+				MozillaEmbed *membed)
+{
+	MozillaEmbedPrivate *mpriv = membed->priv;
+	gint retval = FALSE;
+
+	if (dom_event == NULL) return FALSE;
+
+	nsCOMPtr<nsIDOMKeyEvent> ev = static_cast<nsIDOMKeyEvent*>(dom_event);
+	NS_ENSURE_TRUE (ev, FALSE);
+
+	if (!EventContext::CheckKeyPress (ev)) return FALSE;
+
+	GdkEvent *event = gtk_get_current_event ();
+	if (event == NULL) return FALSE; /* shouldn't happen! */
+
+	g_return_val_if_fail (GDK_KEY_PRESS == event->type, FALSE);
+
+	g_signal_emit_by_name (embed, "ge-search-key-press", event, &retval);
+
+	gdk_event_free (event);
+
+	return retval;
+}
+
 EphyEmbedChrome
 _mozilla_embed_translate_chrome (GtkMozEmbedChromeFlags flags)
 {
@@ -1143,9 +1071,7 @@ ephy_embed_iface_init (EphyEmbedIface *iface)
 	iface->shistory_go_nth = impl_shistory_go_nth;
 	iface->get_security_level = impl_get_security_level;
 	iface->show_page_certificate = impl_show_page_certificate;
-	iface->find_next = impl_find_next;
 	iface->activate = impl_activate;
-	iface->find_set_properties = impl_find_set_properties;
 	iface->set_encoding = impl_set_encoding;
 	iface->get_encoding = impl_get_encoding;
 	iface->has_automatic_encoding = impl_has_automatic_encoding;
@@ -1202,16 +1128,7 @@ _mozilla_embed_new_xul_dialog (void)
 {
 	GtkWidget *window, *embed;
 
-	g_object_ref (embed_shell);
-
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-	g_object_set_data_full (G_OBJECT (window), "EmbedShellRef",
-			        embed_shell,
-				(GDestroyNotify) g_object_unref);
-	g_signal_connect_object (embed_shell, "prepare_close",
-				 G_CALLBACK (gtk_widget_destroy), window,
-				 (GConnectFlags) G_CONNECT_SWAPPED);
-
 	embed = gtk_moz_embed_new ();
 	gtk_widget_show (embed);
 	gtk_container_add (GTK_CONTAINER (window), embed);
