@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: egg-editable-toolbar.c,v 1.69.2.3 2005/07/08 21:15:44 chpe Exp $
+ *  $Id: egg-editable-toolbar.c,v 1.72 2005/06/01 17:19:09 chpe Exp $
  */
 
 #include "config.h"
@@ -47,10 +47,9 @@ static void egg_editable_toolbar_finalize	(GObject *object);
 
 #define MIN_TOOLBAR_HEIGHT 20
 
-static GtkTargetEntry dest_drag_types[] = {
+static const GtkTargetEntry dest_drag_types[] = {
   {EGG_TOOLBAR_ITEM_TYPE, GTK_TARGET_SAME_APP, 0},
 };
-static int n_dest_drag_types = G_N_ELEMENTS (dest_drag_types);
 
 enum
 {
@@ -702,7 +701,7 @@ create_dock (EggEditableToolbar *t)
   gtk_box_pack_start (GTK_BOX (hbox), toolbar, TRUE, TRUE, 0);
 
   gtk_drag_dest_set (toolbar, 0,
-		     dest_drag_types, n_dest_drag_types,
+		     dest_drag_types, G_N_ELEMENTS (dest_drag_types),
 		     GDK_ACTION_MOVE | GDK_ACTION_COPY);
  
   g_signal_connect (toolbar, "drag_drop",
@@ -1412,8 +1411,6 @@ new_pixbuf_from_widget (GtkWidget *widget)
   pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, icon_width, icon_height);
   gdk_pixbuf_get_from_drawable (pixbuf, pixmap, NULL, 0, 0, 0, 0, icon_width, icon_height);
 
-  gtk_widget_destroy (window);
-
   return pixbuf;
 }
 
@@ -1425,6 +1422,7 @@ new_separator_pixbuf ()
 
   separator = gtk_vseparator_new ();
   pixbuf = new_pixbuf_from_widget (separator);
+  gtk_widget_destroy (separator);
   return pixbuf;
 }
 
