@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-langs.c,v 1.15 2005/01/19 15:48:55 chpe Exp $
+ *  $Id: ephy-langs.c,v 1.18 2005/05/01 19:50:35 chpe Exp $
  */
 
 #include "config.h"
@@ -28,10 +28,11 @@
 
 #include <string.h>
 
-#ifdef HAVE_ISO_CODES
 #include <libxml/xmlreader.h>
-#endif
 
+/* If you add more language codes here, remember also to add them in the default font size
+ * section in data/default-prefs-common.js.
+ */
 static const EphyFontsLanguageInfo font_languages [] =
 {
 	/* Translators: The text before the "|" is context to help you decide on
@@ -79,14 +80,42 @@ static const EphyFontsLanguageInfo font_languages [] =
 	/* Translators: The text before the "|" is context to help you decide on
 	 * the correct translation. You MUST OMIT it in the translated string. */
 	{ N_("select fonts for|Turkish"),				"tr" },
+#ifdef HAVE_GECKO_1_8
 	/* Translators: The text before the "|" is context to help you decide on
 	 * the correct translation. You MUST OMIT it in the translated string. */
-	{ N_("select fonts for|Unicode"),				"x-unicode" },
+	{ N_("select fonts for|Armenian"),				"x-armn" },
 	/* Translators: The text before the "|" is context to help you decide on
 	 * the correct translation. You MUST OMIT it in the translated string. */
-	{ N_("select fonts for|Western"),				"x-western" }
+	{ N_("select fonts for|Bengali"),				"x-beng" },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("select fonts for|Unified Canadian Syllabics"),		"x-cans" },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("select fonts for|Ethiopic"),				"x-ethi" },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("select fonts for|Georgian"),				"x-geor" },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("select fonts for|Gujarati"),				"x-gujr" },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("select fonts for|Gurmukhi"),				"x-guru" },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("select fonts for|Khmer"),					"x-khmr" },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("select fonts for|Malayalam"),				"x-mlym" },
+#endif /* HAVE_GECKO_1_8 */
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("select fonts for|Western"),				"x-western" },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("select fonts for|Other Scripts"),				"x-unicode" }
 };
-static const guint n_font_languages = G_N_ELEMENTS (font_languages);
 
 const EphyFontsLanguageInfo *
 ephy_font_languages (void)
@@ -97,7 +126,7 @@ ephy_font_languages (void)
 guint			 
 ephy_font_n_languages (void)
 {
-	return n_font_languages;
+	return G_N_ELEMENTS (font_languages);
 }
 
 /* sanitise the languages list according to the rules for HTTP accept-language
@@ -221,8 +250,6 @@ ephy_langs_get_languages (void)
 	return (char **) g_array_free (array, FALSE);
 }
 
-#ifdef HAVE_ISO_CODES
-
 #define ISOCODESLOCALEDIR	ISO_CODES_PREFIX "/share/locale"
 
 static void
@@ -316,7 +343,7 @@ load_iso_entries (int iso,
 	char *filename;
 	int ret = -1;
 
-	LOG ("Loading ISO-%d codes", iso)
+	LOG ("Loading ISO-%d codes", iso);
 
 	START_PROFILER ("Loading ISO codes")
 
@@ -413,5 +440,3 @@ ephy_langs_iso_3166_table (void)
 
 	return table;
 }
-
-#endif /* HAVE_ISO_CODES */
