@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-state.c,v 1.34 2005/01/07 14:15:34 chpe Exp $
+ *  $Id: ephy-state.c,v 1.35 2005/04/08 13:26:24 chpe Exp $
  */
 
 #include "config.h"
@@ -67,7 +67,7 @@ ephy_states_save (void)
 		 EPHY_STATES_XML_ROOT,
 		 EPHY_STATES_XML_VERSION,
 		 NULL, /* comment */
-		 states, 0,
+		 states, NULL, NULL,
 		 NULL);
 
 	g_free (xml_file);	
