@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-location-entry.c,v 1.57 2005/02/06 14:37:12 chpe Exp $
+ *  $Id: ephy-location-entry.c,v 1.59 2005/04/19 11:14:41 chpe Exp $
  */
 
 #include "config.h"
@@ -32,6 +32,7 @@
 #include "ephy-debug.h"
 
 #include <glib/gi18n.h>
+#include <gdk/gdkkeysyms.h>
 #include <gtk/gtktoolbar.h>
 #include <gtk/gtkentry.h>
 #include <gtk/gtkwindow.h>
@@ -86,13 +87,12 @@ web_prefixes [] =
 	{ "www.", 4 }
 };
 
-static GtkTargetEntry url_drag_types [] =
+static const GtkTargetEntry url_drag_types [] =
 {
 	{ EPHY_DND_URL_TYPE,        0, 0 },
 	{ EPHY_DND_URI_LIST_TYPE,   0, 1 },
 	{ EPHY_DND_TEXT_TYPE,       0, 2 }
 };
-static int n_url_drag_types = G_N_ELEMENTS (url_drag_types);
 
 static void ephy_location_entry_class_init (EphyLocationEntryClass *klass);
 static void ephy_location_entry_init (EphyLocationEntry *le);
@@ -245,6 +245,23 @@ entry_button_press_cb (GtkWidget *entry, GdkEventButton *event, EphyLocationEntr
 	return FALSE;
 }
 
+static gboolean
+entry_key_press_cb (GtkWidget *widget,
+		    GdkEventKey *event,
+		    EphyLocationEntry *entry)
+{
+	if (event->keyval == GDK_Escape)
+	{
+		ephy_location_entry_restore_location (entry);
+
+		/* Don't consume the keypress, since we want the default
+		 * action (close autocompletion popup) too.
+		 */
+	}
+
+	return FALSE;
+}
+
 static gboolean
 keyword_match (const char *list,
 	       const char *keyword)
@@ -550,7 +567,7 @@ ephy_location_entry_construct_contents (EphyLocationEntry *entry)
 	gtk_event_box_set_visible_window (GTK_EVENT_BOX (priv->icon_ebox), FALSE);
 	gtk_box_pack_start (GTK_BOX (hbox), priv->icon_ebox, FALSE, FALSE, 2);
 	gtk_drag_source_set (priv->icon_ebox, GDK_BUTTON1_MASK,
-			     url_drag_types, n_url_drag_types,
+			     url_drag_types, G_N_ELEMENTS (url_drag_types),
 			     GDK_ACTION_ASK | GDK_ACTION_COPY | GDK_ACTION_LINK);
 	gtk_tooltips_set_tip (priv->tips, priv->icon_ebox,
 			      _("Drag and drop this icon to create a link to this page"), NULL);
@@ -586,6 +603,8 @@ ephy_location_entry_construct_contents (EphyLocationEntry *entry)
 			  G_CALLBACK (entry_populate_popup_cb), entry);
 	g_signal_connect (priv->entry, "button_press_event",
 			  G_CALLBACK (entry_button_press_cb), entry);
+	g_signal_connect (priv->entry, "key-press-event",
+			  G_CALLBACK (entry_key_press_cb), entry);
 	g_signal_connect (priv->entry, "changed",
 			  G_CALLBACK (editable_changed_cb), entry);
 	g_signal_connect (priv->entry, "drag_motion",
@@ -701,6 +720,18 @@ ephy_location_entry_get_location (EphyLocationEntry *le)
 	return gtk_entry_get_text (GTK_ENTRY (le->priv->entry));
 }
 
+void
+ephy_location_entry_restore_location (EphyLocationEntry *entry)
+{
+	char *url = NULL;
+
+	g_return_if_fail (EPHY_IS_LOCATION_ENTRY (entry));
+
+	g_signal_emit (entry, signals[GET_LOCATION], 0, &url);
+	gtk_entry_set_text (GTK_ENTRY (entry->priv->entry), url ? url : "");
+	g_free (url);
+}
+
 void
 ephy_location_entry_activate (EphyLocationEntry *le)
 {
