@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-bookmarks-editor.c,v 1.170 2005/01/28 22:25:02 chpe Exp $
+ * $Id: ephy-bookmarks-editor.c,v 1.171 2005/04/19 10:17:31 chpe Exp $
  */
 
 #include "config.h"
@@ -1261,28 +1261,28 @@ ephy_bookmarks_editor_update_menu (EphyBookmarksEditor *editor)
 
 	action_group = editor->priv->action_group;
 	action = gtk_action_group_get_action (action_group, "OpenInWindow");
-	g_object_set (action, "sensitive", open_in_window,
-			      "label", open_in_window_label, NULL);
+	gtk_action_set_sensitive (action, open_in_window);
+	g_object_set (action, "label", open_in_window_label, NULL);
 	action = gtk_action_group_get_action (action_group, "OpenInTab");
-	g_object_set (action, "sensitive", open_in_tab,
-			      "label", open_in_tab_label, NULL);
+	gtk_action_set_sensitive (action, open_in_tab);
+	g_object_set (action,  "label", open_in_tab_label, NULL);
 	action = gtk_action_group_get_action (action_group, "Rename");
-	g_object_set (action, "sensitive", rename, NULL);
+	gtk_action_set_sensitive (action, rename);
 	action = gtk_action_group_get_action (action_group, "Delete");
-	g_object_set (action, "sensitive", delete, NULL);
+	gtk_action_set_sensitive (action, delete);
 	action = gtk_action_group_get_action (action_group, "Properties");
-	g_object_set (action, "sensitive", properties, NULL);
+	gtk_action_set_sensitive (action, properties);
 	action = gtk_action_group_get_action (action_group, "Cut");
-	g_object_set (action, "sensitive", cut, NULL);
+	gtk_action_set_sensitive (action, cut);
 	action = gtk_action_group_get_action (action_group, "Copy");
-	g_object_set (action, "sensitive", copy,
-			      "label", copy_label, NULL);
+	gtk_action_set_sensitive (action, copy);
+	g_object_set (action, "label", copy_label, NULL);
 	action = gtk_action_group_get_action (action_group, "Paste");
-	g_object_set (action, "sensitive", paste, NULL);
+	gtk_action_set_sensitive (action, paste);
 	action = gtk_action_group_get_action (action_group, "SelectAll");
-	g_object_set (action, "sensitive", select_all, NULL);
+	gtk_action_set_sensitive (action, select_all);
 	action = gtk_action_group_get_action (action_group, "ShowInBookmarksBar");
-	g_object_set (action, "sensitive", can_show_in_bookmarks_bar, NULL);
+	gtk_action_set_sensitive (action, can_show_in_bookmarks_bar);
 
 	g_signal_handlers_block_by_func
 		(G_OBJECT (GTK_TOGGLE_ACTION (action)),
