@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-notebook.c,v 1.70.2.2 2005/05/30 22:40:35 chpe Exp $
+ *  $Id: ephy-notebook.c,v 1.74 2005/05/30 22:39:33 chpe Exp $
  */
 
 #include "config.h"
@@ -70,9 +70,12 @@ struct _EphyNotebookPrivate
 	GtkTooltips *title_tips;
 	guint tabs_vis_notifier_id;
 	gulong motion_notify_handler_id;
-	gint x_start, y_start;
-	gboolean drag_in_progress;
-	gboolean show_tabs;
+	int x_start;
+	int y_start;
+
+	guint drag_in_progress : 1;
+	guint show_tabs : 1;
+	guint dnd_enabled : 1;
 };
 
 static void ephy_notebook_init           (EphyNotebook *notebook);
@@ -86,12 +89,18 @@ static void move_tab_to_another_notebook (EphyNotebook *src,
 /* Local variables */
 static GdkCursor *cursor = NULL;
 
-static GtkTargetEntry url_drag_types [] = 
+static const GtkTargetEntry url_drag_types [] = 
 {
         { EPHY_DND_URI_LIST_TYPE,   0, 0 },
         { EPHY_DND_URL_TYPE,        0, 1 }
 };
-static guint n_url_drag_types = G_N_ELEMENTS (url_drag_types);
+
+enum
+{
+	PROP_0,
+	PROP_DND_ENABLED,
+	PROP_SHOW_TABS
+};
 
 enum
 {
@@ -145,6 +154,57 @@ ephy_notebook_get_type (void)
 	return type;
 }
 
+void
+ephy_notebook_set_dnd_enabled (EphyNotebook *notebook,
+			       gboolean enabled)
+{
+	EphyNotebookPrivate *priv = notebook->priv;
+
+	priv->dnd_enabled = enabled;
+	/* FIXME abort any DNDs in progress */
+
+	g_object_notify (G_OBJECT (notebook), "dnd-enabled");
+}
+
+static void
+ephy_notebook_get_property (GObject *object,
+			    guint prop_id,
+			    GValue *value,
+			    GParamSpec *pspec)
+{
+	EphyNotebook *notebook = EPHY_NOTEBOOK (object);
+	EphyNotebookPrivate *priv = notebook->priv;
+
+	switch (prop_id)
+	{
+		case PROP_DND_ENABLED:
+			g_value_set_boolean (value, priv->dnd_enabled);
+			break;
+		case PROP_SHOW_TABS:
+			g_value_set_boolean (value, priv->show_tabs);
+			break;
+	}
+}
+
+static void
+ephy_notebook_set_property (GObject *object,
+			    guint prop_id,
+			    const GValue *value,
+			    GParamSpec *pspec)
+{
+	EphyNotebook *notebook = EPHY_NOTEBOOK (object);
+
+	switch (prop_id)
+	{
+		case PROP_DND_ENABLED:
+			ephy_notebook_set_dnd_enabled (notebook, g_value_get_boolean (value));
+			break;
+		case PROP_SHOW_TABS:
+			ephy_notebook_set_show_tabs (notebook, g_value_get_boolean (value));
+			break;
+	}
+}
+
 static void
 ephy_notebook_class_init (EphyNotebookClass *klass)
 {
@@ -153,6 +213,8 @@ ephy_notebook_class_init (EphyNotebookClass *klass)
 	parent_class = g_type_class_peek_parent (klass);
 
 	object_class->finalize = ephy_notebook_finalize;
+	object_class->get_property = ephy_notebook_get_property;
+	object_class->set_property = ephy_notebook_set_property;
 
 	signals[TAB_ADDED] =
 		g_signal_new ("tab_added",
@@ -204,7 +266,23 @@ ephy_notebook_class_init (EphyNotebookClass *klass)
 			      1,
 			      EPHY_TYPE_TAB);
 
-	g_type_class_add_private (object_class, sizeof(EphyNotebookPrivate));
+	g_object_class_install_property (object_class,
+					 PROP_DND_ENABLED,
+					 g_param_spec_boolean ("dnd-enabled",
+							       "DND enabled",
+							       "Whether the notebook allows tab reordering by DND",
+							       TRUE,
+							       G_PARAM_READWRITE));
+
+	g_object_class_install_property (object_class,
+					 PROP_SHOW_TABS,
+					 g_param_spec_boolean ("show-tabs",
+							       "Show tabs",
+							       "Whether the notebook shows the tabs bar",
+							       TRUE,
+							       G_PARAM_READWRITE));
+
+	g_type_class_add_private (object_class, sizeof (EphyNotebookPrivate));
 }
 
 static EphyNotebook *
@@ -482,6 +560,9 @@ move_tab_to_another_notebook (EphyNotebook *src,
 	g_assert (EPHY_IS_NOTEBOOK (dest));
 	g_assert (dest != src);
 
+	/* Check if the dest notebook can accept the drag */
+	if (!dest->priv->dnd_enabled) return;
+
 	cur_page = gtk_notebook_get_current_page (GTK_NOTEBOOK (src));
 	tab = EPHY_TAB (gtk_notebook_get_nth_page (GTK_NOTEBOOK (src), cur_page));
 
@@ -552,10 +633,13 @@ button_press_cb (EphyNotebook *notebook,
 		 GdkEventButton *event,
 		 gpointer data)
 {
-	gint tab_clicked = find_tab_num_at_pos (notebook,
-						event->x_root,
-						event->y_root);
+	int tab_clicked;
 
+	if (!notebook->priv->dnd_enabled) return FALSE;
+
+	tab_clicked = find_tab_num_at_pos (notebook, event->x_root, event->y_root);
+
+	/* FIXME: how could there be a drag in progress!? */
 	if (notebook->priv->drag_in_progress)
 	{
 		return TRUE;
@@ -714,6 +798,7 @@ ephy_notebook_init (EphyNotebook *notebook)
 	gtk_object_sink (GTK_OBJECT (notebook->priv->title_tips));
 
 	notebook->priv->show_tabs = TRUE;
+	notebook->priv->dnd_enabled = TRUE;
 
 	g_signal_connect (notebook, "button-press-event",
 			  (GCallback)button_press_cb, NULL);
@@ -731,7 +816,7 @@ ephy_notebook_init (EphyNotebook *notebook)
 			  NULL);
         gtk_drag_dest_set (GTK_WIDGET(notebook), GTK_DEST_DEFAULT_MOTION |
 			   GTK_DEST_DEFAULT_DROP,
-                           url_drag_types,n_url_drag_types,
+                           url_drag_types, G_N_ELEMENTS (url_drag_types),
                            GDK_ACTION_MOVE | GDK_ACTION_COPY);
 
 	notebook->priv->tabs_vis_notifier_id = eel_gconf_notification_add
@@ -972,7 +1057,7 @@ ephy_notebook_add_tab (EphyNotebook *nb,
 	g_signal_connect (G_OBJECT(label), "drag_data_received",
 			  G_CALLBACK(notebook_drag_data_received_cb), tab);
 	gtk_drag_dest_set (label, GTK_DEST_DEFAULT_ALL,
-			   url_drag_types,n_url_drag_types,
+			   url_drag_types, G_N_ELEMENTS (url_drag_types),
 			   GDK_ACTION_MOVE | GDK_ACTION_COPY);
 
 	sync_icon (tab, NULL, label);
