@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-session.c,v 1.39.2.1 2005/07/04 12:14:56 chpe Exp $
+ *  $Id: ephy-session.c,v 1.40 2005/04/17 19:38:59 chpe Exp $
  */
 
 #include "config.h"
@@ -57,8 +57,7 @@ struct _EphySessionPrivate
 	GList *windows;
 	GList *tool_windows;
 	GtkWidget *resume_dialog;
-	guint dont_save : 1;
-	guint quit_while_resuming : 1;
+	gboolean dont_save;
 };
 
 #define BOOKMARKS_EDITOR_ID	"BookmarksEditor"
@@ -262,29 +261,41 @@ impl_detach_window (EphyExtension *extension,
 	 */
 }
 
+static void
+ensure_session_directory (void)
+{
+	char *dir;
+
+	dir = g_build_filename (ephy_dot_dir (), "sessions", NULL);
+	if (g_file_test (dir, G_FILE_TEST_EXISTS) == FALSE)
+	{
+		if (mkdir (dir, 488) != 0)
+		{
+			g_error ("Unable to create session directory '%s'\n", dir);
+		}
+	}
+
+	g_free (dir);
+}
+
 static void
 ephy_session_init (EphySession *session)
 {
 	session->priv = EPHY_SESSION_GET_PRIVATE (session);
 
 	LOG ("EphySession initialising");
+
+	ensure_session_directory ();
 }
 
 static void
 ephy_session_dispose (GObject *object)
 {
 	EphySession *session = EPHY_SESSION(object);
-	EphySessionPrivate *priv = session->priv;
 
 	LOG ("EphySession disposing");
 
-	/* Only remove the crashed session if we're not shutting down while
-	 * the session resume dialogue was still shown!
-	*/
-	if (priv->quit_while_resuming == FALSE)
-	{
-		session_delete (session, SESSION_CRASHED);
-	}
+	session_delete (session, SESSION_CRASHED);
 
 	parent_class->dispose (object);
 }
@@ -451,25 +462,12 @@ ephy_session_autoresume (EphySession *session,
 
 	g_free (saved_session);
 
-	/* ensure we don't open a blank window when quitting while resuming */
-	return retval || priv->quit_while_resuming;
-}
-
-static void
-close_dialog (GtkWidget *widget)
-{
-	if (GTK_IS_DIALOG (widget))
-	{
-		/* don't destroy them, someone might have a ref on them */
-		gtk_dialog_response (GTK_DIALOG (widget),
-				     GTK_RESPONSE_DELETE_EVENT);
-	}
+	return retval;
 }
 
 void
 ephy_session_close (EphySession *session)
 {
-	EphySessionPrivate *priv = session->priv;
 	GList *windows;
 
 	LOG ("ephy_session_close");
@@ -478,12 +476,7 @@ ephy_session_close (EphySession *session)
 	 * destroying the windows and destroying the tool windows
 	 */
 	g_object_ref (ephy_shell);
-
-	priv->dont_save = TRUE;
-	/* need to set this up here while the dialogue hasn't been killed yet */
-	priv->quit_while_resuming = priv->resume_dialog != NULL;	
-
-	ephy_embed_shell_prepare_close (embed_shell);
+	session->priv->dont_save = TRUE;
 
 	windows	= ephy_session_get_windows (session);
 	g_list_foreach (windows, (GFunc) gtk_widget_destroy, NULL);
@@ -493,17 +486,6 @@ ephy_session_close (EphySession *session)
 	g_list_foreach (windows, (GFunc) gtk_widget_destroy, NULL);
 	g_list_free (windows);	
 
-	ephy_embed_shell_prepare_close (embed_shell);
-
-	/* there may still be windows open, like dialogues posed from
-	 * web pages, etc. Try to kill them, but be sure NOT to destroy
-	 * the gtkmozembed offscreen window!
-	 * Here, we just check if it's a dialogue and close it if it is one.
-	 */
-	windows = gtk_window_list_toplevels ();
-	g_list_foreach (windows, (GFunc) close_dialog, NULL);
-	g_list_free (windows);
-
 	session->priv->dont_save = FALSE;
 	g_object_unref (ephy_shell);
 }
@@ -944,20 +926,22 @@ ephy_session_remove_window (EphySession *session,
  * need to take an action (like opening an url) on
  * a window but you dont have a target window.
  *
- * Return value: the current active browser window, or NULL of there is none.
+ * Return value: the current active non-popup browser window, or NULL of there is none.
  **/
 EphyWindow *
 ephy_session_get_active_window (EphySession *session)
 {
-	GList *first;
+	EphyWindow *window = NULL;
+	GList *l;
 
 	g_return_val_if_fail (EPHY_IS_SESSION (session), NULL);
 
-	first = session->priv->windows;
-	if (first != NULL)
+	for (l = session->priv->windows; l != NULL; l = l->next)
 	{
-		return EPHY_WINDOW (first->data);
+		window = EPHY_WINDOW (l->data);
+
+		if (ephy_window_get_is_popup (window) == FALSE) break;
 	}
 
-	return NULL;
+	return window;
 }
