@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id$
+ *  $Id: ephy-shell.c,v 1.123 2005/05/23 08:43:08 jframeau Exp $
  */
 
 #include "config.h"
@@ -38,6 +38,7 @@
 #include "ephy-debug.h"
 #include "ephy-extensions-manager.h"
 #include "ephy-session.h"
+#include "ephy-lockdown.h"
 #include "downloader-view.h"
 #include "egg-toolbars-model.h"
 #include "ephy-toolbars-model.h"
@@ -70,6 +71,7 @@ struct _EphyShellPrivate
 {
 	BonoboGenericFactory *automation_factory;
 	EphySession *session;
+	GObject *lockdown;
 	EphyBookmarks *bookmarks;
 	EggToolbarsModel *toolbars_model;
 	EggToolbarsModel *fs_toolbars_model;
@@ -158,6 +160,7 @@ ephy_shell_new_window_cb (EphyEmbedSingle *single,
 {
 	GtkWidget *parent = NULL;
 	EphyTab *new_tab;
+	gboolean is_popup;
 	EphyNewTabFlags flags = EPHY_NEW_TAB_DONT_SHOW_WINDOW |
 				EPHY_NEW_TAB_APPEND_LAST |
 				EPHY_NEW_TAB_IN_NEW_WINDOW |
@@ -179,10 +182,15 @@ ephy_shell_new_window_cb (EphyEmbedSingle *single,
 		parent = gtk_widget_get_toplevel (GTK_WIDGET (parent_embed));
 	}
 
+	/* what's a popup ? ATM, any window opened with menubar toggled on 
+   	 * is *not* a popup 
+	 */
+	is_popup = (chromemask & EPHY_EMBED_CHROME_MENUBAR) == 0;
+
 	new_tab = ephy_shell_new_tab_full
 		(shell,
 		 EPHY_IS_WINDOW (parent) ? EPHY_WINDOW (parent) : NULL,
-		 NULL, NULL, flags, chromemask, 0);
+		 NULL, NULL, flags, chromemask, is_popup, 0);
 
 	return ephy_tab_get_embed (new_tab);
 }
@@ -472,13 +480,8 @@ ephy_shell_startup (EphyShell *shell,
 				       "from Bonobo when attempting to locate the automation "
 				       "object."));
 			automation = NULL;
-			goto done;
 		}
-
-		/* init the session manager up here so we can quit while the resume dialogue is on */
-		gnome_session_init (shell);
-
-		if (flags & EPHY_SHELL_STARTUP_BOOKMARKS_EDITOR)
+		else if (flags & EPHY_SHELL_STARTUP_BOOKMARKS_EDITOR)
 		{
 			GNOME_EphyAutomation_openBookmarksEditorWithStartupId
 				(automation, user_time, &ev);
@@ -506,10 +509,14 @@ ephy_shell_startup (EphyShell *shell,
 				   flags & EPHY_SHELL_STARTUP_FULLSCREEN);
 		}
 
-		bonobo_object_release_unref (automation, &ev);
+		if (automation)
+		{
+			bonobo_object_release_unref (automation, &ev);
+		}
+
+		gnome_session_init (shell);
 	}
 
-done:
 	CORBA_exception_free (&ev);
 	gdk_notify_startup_complete ();
 
@@ -544,6 +551,12 @@ ephy_shell_finalize (GObject *object)
 		g_object_unref (shell->priv->session);
 	}
 
+	LOG ("Unref lockdown controller");
+	if (shell->priv->lockdown)
+	{
+		g_object_unref (shell->priv->lockdown);
+	}
+
 	LOG ("Unref toolbars model");
 	if (shell->priv->toolbars_model)
 	{
@@ -625,25 +638,10 @@ ephy_shell_new (void)
 	return EPHY_SHELL (g_object_new (EPHY_TYPE_SHELL, NULL));
 }
 
-static gboolean
-url_is_empty (const char *location)
-{
-	gboolean is_empty = FALSE;
-
-        if (location == NULL || location[0] == '\0' ||
-            strcmp (location, "about:blank") == 0)
-        {
-                is_empty = TRUE;
-        }
-
-        return is_empty;
-}
-
-static gboolean
+static void
 load_homepage (EphyEmbed *embed)
 {
 	char *home;
-	gboolean is_empty;
 
 	home = eel_gconf_get_string(CONF_GENERAL_HOMEPAGE);
 
@@ -654,13 +652,9 @@ load_homepage (EphyEmbed *embed)
 		home = g_strdup ("about:blank");
 	}
 
-	is_empty = url_is_empty (home);
-
 	ephy_embed_load_url (embed, home);
 
 	g_free (home);
-
-	return is_empty;
 }
 
 /**
@@ -670,6 +664,7 @@ load_homepage (EphyEmbed *embed)
  * @previous_tab: the referrer tab or %NULL
  * @url: an url to load or %NULL
  * @chrome: a #EphyEmbedChrome mask to use if creating a new window
+ * @is_popup: whether the new window is a popup
  * @user_time: a timestamp, or 0
  *
  * Create a new tab and the parent window when necessary.
@@ -684,6 +679,7 @@ ephy_shell_new_tab_full (EphyShell *shell,
 			 const char *url,
 			 EphyNewTabFlags flags,
 			 EphyEmbedChrome chrome,
+			 gboolean is_popup,
 			 guint32 user_time)
 {
 	EphyWindow *window;
@@ -694,13 +690,13 @@ ephy_shell_new_tab_full (EphyShell *shell,
 	EphyEmbed *previous_embed = NULL;
 	GtkWidget *nb;
 	int position = -1;
-	gboolean is_empty = FALSE;
 	EphyToolbar *toolbar;
 
 	if (flags & EPHY_NEW_TAB_IN_NEW_WINDOW) in_new_window = TRUE;
 	if (flags & EPHY_NEW_TAB_IN_EXISTING_WINDOW) in_new_window = FALSE;
 
 	in_new_window = in_new_window && !eel_gconf_get_boolean (CONF_LOCKDOWN_FULLSCREEN);
+	g_return_val_if_fail (in_new_window || !is_popup, NULL);
 
 	jump_to = (flags & EPHY_NEW_TAB_JUMP) != 0;
 
@@ -713,7 +709,7 @@ ephy_shell_new_tab_full (EphyShell *shell,
 	}
 	else
 	{
-		window = ephy_window_new_with_chrome (chrome);
+		window = ephy_window_new_with_chrome (chrome, is_popup);
 	}
 
 	toolbar = EPHY_TOOLBAR (ephy_window_get_toolbar (window));
@@ -753,36 +749,14 @@ ephy_shell_new_tab_full (EphyShell *shell,
 	{
 		ephy_tab_set_location (tab, "", EPHY_TAB_ADDRESS_EXPIRE_NEXT);
 		ephy_toolbar_activate_location (toolbar);
-		is_empty = load_homepage (embed);
+		load_homepage (embed);
 	}
 	else if (flags & EPHY_NEW_TAB_OPEN_PAGE)
 	{
 		g_assert (url != NULL);
 		ephy_embed_load_url (embed, url);
-		is_empty = url_is_empty (url);
 	}
 
-        /* Make sure the initial focus is somewhere sensible and not, for
-         * example, on the reload button.
-         */
-        if (in_new_window || jump_to)
-        {
-                /* If the location entry is blank, focus that, except if the
-                 * page was a copy */
-                if (is_empty)
-                {
-                        /* empty page, focus location entry */
-			toolbar = EPHY_TOOLBAR (ephy_window_get_toolbar (window));
-			ephy_toolbar_activate_location (toolbar);
-                }
-                else if (embed != NULL) 
-                {
-			/* non-empty page, focus the page. but make sure the widget is realised first! */
-			gtk_widget_realize (GTK_WIDGET (embed));
-			ephy_embed_activate (embed);
-                }
-        }
-
 	return tab;
 }
 
@@ -807,7 +781,7 @@ ephy_shell_new_tab (EphyShell *shell,
 {
 	return ephy_shell_new_tab_full (shell, parent_window,
 					previous_tab, url, flags,
-					EPHY_EMBED_CHROME_ALL, 0);
+					EPHY_EMBED_CHROME_ALL, FALSE, 0);
 }
 
 /**
@@ -838,6 +812,34 @@ ephy_shell_get_session (EphyShell *shell)
 	return G_OBJECT (shell->priv->session);
 }
 
+/**
+ * ephy_shell_get_lockdown:
+ * @shell: the #EphyShell
+ *
+ * Returns the lockdown controller.
+ *
+ * Return value: the lockdown controller
+ **/
+static GObject *
+ephy_shell_get_lockdown (EphyShell *shell)
+{
+	g_return_val_if_fail (EPHY_IS_SHELL (shell), NULL);
+
+	if (shell->priv->lockdown == NULL)
+	{
+		EphyExtensionsManager *manager;
+
+		shell->priv->lockdown = g_object_new (EPHY_TYPE_LOCKDOWN, NULL);
+
+		manager = EPHY_EXTENSIONS_MANAGER
+			(ephy_shell_get_extensions_manager (shell));
+		ephy_extensions_manager_register (manager,
+						  G_OBJECT (shell->priv->lockdown));
+	}
+
+	return G_OBJECT (shell->priv->session);
+}
+
 EphyBookmarks *
 ephy_shell_get_bookmarks (EphyShell *shell)
 {
@@ -909,6 +911,9 @@ ephy_shell_get_extensions_manager (EphyShell *es)
 			g_object_new (EPHY_TYPE_EXTENSIONS_MANAGER, NULL);
 
 		ephy_extensions_manager_startup (es->priv->extensions_manager);
+
+		/* FIXME */
+		ephy_shell_get_lockdown (es);
 	}
 
 	return G_OBJECT (es->priv->extensions_manager);
