@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-window.h,v 1.34 2005/01/08 16:32:09 chpe Exp $
+ *  $Id: ephy-window.h,v 1.37 2005/05/29 16:11:06 chpe Exp $
  */
 
 #ifndef EPHY_WINDOW_H
@@ -58,7 +58,8 @@ GType		  ephy_window_get_type		  (void);
 
 EphyWindow	 *ephy_window_new		  (void);
 
-EphyWindow	 *ephy_window_new_with_chrome	  (EphyEmbedChrome chrome);
+EphyWindow	 *ephy_window_new_with_chrome	  (EphyEmbedChrome chrome,
+						   gboolean is_popup);
 
 void		  ephy_window_set_print_preview	  (EphyWindow *window,
 						   gboolean enabled);
@@ -71,6 +72,8 @@ GtkWidget	 *ephy_window_get_bookmarksbar	  (EphyWindow *window);
 
 GtkWidget	 *ephy_window_get_notebook	  (EphyWindow *window);
 
+GtkWidget        *ephy_window_get_find_toolbar    (EphyWindow *window);
+
 GtkWidget	 *ephy_window_get_statusbar	  (EphyWindow *window);
 
 void		  ephy_window_add_tab		  (EphyWindow *window,
@@ -100,6 +103,10 @@ GList		 *ephy_window_get_tabs		  (EphyWindow *window);
 
 void		  ephy_window_find		  (EphyWindow *window);
 
+gboolean	  ephy_window_get_is_popup	  (EphyWindow *window);
+
+gboolean	  ephy_window_get_is_print_preview(EphyWindow *window);
+
 G_END_DECLS
 
 #endif
