@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: prefs-dialog.c,v 1.108.2.1 2005/07/29 22:28:29 chpe Exp $
+ *  $Id: prefs-dialog.c,v 1.110 2005/05/01 19:48:05 chpe Exp $
  */
 
 #include "config.h"
@@ -87,262 +87,12 @@ void language_editor_up_button_clicked_cb	(GtkWidget *button,
 void language_editor_down_button_clicked_cb	(GtkWidget *button,
 						 PrefsDialog *pd);
 
-#ifdef HAVE_ISO_CODES
-static const char *languages[] =
-{
-	/* If you're missing your language/locale combination, file a bug at
-	 * http://bugzilla.gnome.org/enter_bug.cgi?product=epiphany
-	 */
-	"af",
-	"am",
-	"an",
-	"ar",
-	"ar-ae",
-	"ar-bh",
-	"ar-dz",
-	"ar-eg",
-	"ar-iq",
-	"ar-jo",
-	"ar-kw",
-	"ar-lb",
-	"ar-ly",
-	"ar-ma",
-	"ar-om",
-	"ar-qa",
-	"ar-sa",
-	"ar-sy",
-	"ar-tn",
-	"ar-ye",
-	"ast",
-	"az",
-	"be",
-	"bg",
-	"bn",
-	"br",
-	"bs",
-	"ca",
-	"ce",
-	"ch",
-	"co",
-	"cs",
-	"cv",
-	"cy",
-	"da",
-	"de",
-	"de-at",
-	"de-ch",
-	"de-de",
-	"de-li",
-	"de-lu",
-	"el",
-	"en",
-	"en-au",
-	"en-bz",
-	"en-ca",
-	"en-gb",
-	"en-ie",
-	"en-jm",
-	"en-nz",
-	"en-ph",
-	"en-tt",
-	"en-us",
-	"en-za",
-	"en-zw",
-	"eo",
-	"es",
-	"es-ar",
-	"es-bo",
-	"es-cl",
-	"es-co",
-	"es-cr",
-	"es-do",
-	"es-ec",
-	"es-es",
-	"es-gt",
-	"es-hn",
-	"es-mx",
-	"es-ni",
-	"es-pa",
-	"es-pe",
-	"es-pr",
-	"es-py",
-	"es-sv",
-	"es-uy",
-	"es-ve",
-	"et",
-	"eu",
-	"fa",
-	"fi",
-	"fj",
-	"fo",
-	"fr",
-	"fr-be",
-	"fr-ca",
-	"fr-ch",
-	"fr-fr",
-	"fr-lu",
-	"fr-mc",
-	"fy",
-	"ga",
-	"gd",
-	"gl",
-	"gu",
-	"he",
-	"hsb",
-	"hi",
-	"hr",
-	"ht",
-	"hu",
-	"hy",
-	"ia",
-	"id",
-	"ie",
-	"is",
-	"it",
-	"it-ch",
-	"it-it",
-	"iu",
-	"ja",
-	"ka",
-	"kk",
-	"ko",
-	"ko-kp",
-	"ko-kr",
-	"ky",
-	"la",
-	"lb",
-	"li",
-	"lt",
-	"lv",
-	"mi",
-	"mk-mk",
-	"ml",
-	"mn",
-	"mo",
-	"mr",
-	"ms",
-	"nb",
-	"ne",
-	"ng",
-	"nl",
-	"nl-be",
-	"nn",
-	"no",
-	"nv",
-	"oc",
-	"om",
-	"pa",
-	"pl",
-	"pt",
-	"pt-br",
-	"qu",
-	"rm",
-	"ro",
-	"ru",
-	"sa",
-	"sc",
-	"sd",
-	"sg",
-	"sk",
-	"sl",
-	"so",
-	"sq",
-	"sr",
-	"sv",
-	"sv-fi",
-	"sw",
-	"ta",
-	"th",
-	"tk",
-	"tr",
-	"uk",
-	"ve",
-	"vi",
-	"vo",
-	"wa",
-	"xh",
-	"yi",
-	"zh",
-	"zh-cn",
-	"zh-hk",
-	"zh-sg",
-	"zh-tw",
-	"zu"
-};
-#else
-static const
-struct
-{
-	char *code;
-	char *name;
-}
-languages [] =
-{
-	{ "af",		N_("Afrikaans") },
-	{ "ar",		N_("Arabic") },
-	{ "az",		N_("Azerbaijani") },
-	{ "be",		N_("Byelorussian") },
-	{ "bg",		N_("Bulgarian") },
-	{ "br",		N_("Breton") },
-	{ "ca",		N_("Catalan") },
-	{ "cs",		N_("Czech") },
-	{ "da",		N_("Danish") },
-	{ "de",		N_("German") },
-	{ "en",		N_("English") },
-	{ "el",		N_("Greek") },
-	{ "eo",		N_("Esperanto") },
-	{ "es",		N_("Spanish") },
-	{ "et",		N_("Estonian") },
-	{ "eu",		N_("Basque") },
-	{ "fi",		N_("Finnish") },
-	{ "fo",		N_("Faeroese") },
-	{ "fr",		N_("French") },
-	{ "ga",		N_("Irish") },
-	{ "gd",		N_("Scots Gaelic") },
-	{ "gl",		N_("Galician") },
-	{ "he",		N_("Hebrew") },
-	{ "hr",		N_("Croatian") },
-	{ "hu",		N_("Hungarian") },
-	{ "id",		N_("Indonesian") },
-	{ "is",		N_("Icelandic") },
-	{ "it",		N_("Italian") },
-	{ "ja",		N_("Japanese") },
-	{ "ko",		N_("Korean") },
-	{ "lt",		N_("Lithuanian") },
-	{ "lv",		N_("Latvian") },
-	{ "mk",		N_("Macedonian") },
-	{ "ms",		N_("Malay") },
-	{ "nl",		N_("Dutch") },
-	{ "nb",		N_("Norwegian/Bokmal") },
-	{ "nn",		N_("Norwegian/Nynorsk") },
-	{ "no",		N_("Norwegian") },
-	{ "pl",		N_("Polish") },
-	{ "pt",		N_("Portuguese") },
-	{ "pt-br",	N_("Portuguese of Brazil") },
-	{ "ro",		N_("Romanian") },
-	{ "ru",		N_("Russian") },
-	{ "sk",		N_("Slovak") },
-	{ "sl",		N_("Slovenian") },
-	{ "sq",		N_("Albanian") },
-	{ "sr",		N_("Serbian") },
-	{ "sv",		N_("Swedish") },
-	{ "ta",		N_("Tamil") },
-	{ "tr",		N_("Turkish") },
-	{ "uk",		N_("Ukrainian") },
-	{ "vi",		N_("Vietnamese") },
-	{ "wa",		N_("Walloon") },
-	{ "zh",		N_("Chinese") },
-	{ "zh-cn",	N_("Simplified Chinese") },
-	{ "zh-tw",	N_("Traditional Chinese") }
-};
-#endif /* HAVE_ISO_CODES */
+#include "languages.h"
 
-static const
-char *cookies_accept_enum [] =
+static const char * const cookies_accept_enum [] =
 {
 	"anywhere", "current site", "nowhere"
 };
-static guint n_cookies_accept_enum = G_N_ELEMENTS (cookies_accept_enum);
 
 enum
 {
@@ -350,8 +100,7 @@ enum
 	FONT_TYPE_MONOSPACE
 };
 
-const
-char *fonts_types[] =
+static const char * const fonts_types[] =
 {
 	"variable",
 	"monospace"
@@ -364,8 +113,7 @@ enum
 	FONT_SIZE_MIN
 };
 
-const
-char *size_prefs [] =
+static const char * const size_prefs [] =
 {
 	CONF_RENDERING_FONT_FIXED_SIZE,
 	CONF_RENDERING_FONT_VAR_SIZE,
@@ -512,14 +260,13 @@ struct PrefsDialogPrivate
 	GtkWidget *lang_remove_button;
 	GtkWidget *lang_up_button;
 	GtkWidget *lang_down_button;
-#ifdef HAVE_ISO_CODES
 	GHashTable *iso_639_table;
 	GHashTable *iso_3166_table;
-#endif
 };
 
 /* gtk+' gettext domain */
 #define GTK_DOMAIN "gtk20"
+#define DGETTEXT_GTK_(x) dgettext(GTK_DOMAIN, x)
 
 static GObjectClass *parent_class = NULL;
 
@@ -571,10 +318,8 @@ prefs_dialog_finalize (GObject *object)
 			 (gpointer *) &dialog->priv->download_dir_chooser);
 	}
 
-#ifdef HAVE_ISO_CODES
 	g_hash_table_destroy (dialog->priv->iso_639_table);
 	g_hash_table_destroy (dialog->priv->iso_3166_table);
-#endif
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -597,7 +342,7 @@ prefs_dialog_show_help (EphyDialog *dialog)
 	GtkWidget *window, *notebook;
 	int id;
 
-	char *help_preferences[] = {
+	static char * const help_preferences[] = {
 		"general-preferences",
 		"fonts-and-colors-preferences",
 		"privacy-preferences",
@@ -981,7 +726,6 @@ add_lang_dialog_response_cb (GtkWidget *widget,
 	g_object_unref (dialog);
 }
 
-#ifdef HAVE_ISO_CODES
 static char *
 get_name_for_lang_code (PrefsDialog *pd,
 			const char *code)
@@ -1039,7 +783,6 @@ get_name_for_lang_code (PrefsDialog *pd,
 
 	return name;
 }
-#endif /* HAVE_ISO_CODES */
 
 static void
 add_system_language_entry (GtkListStore *store)
@@ -1101,7 +844,6 @@ setup_add_language_dialog (PrefsDialog *pd)
 
 	for (i = 0; i < G_N_ELEMENTS (languages); i++)
 	{
-#ifdef HAVE_ISO_CODES
 		const char *code = languages[i];
 		char *name;
 
@@ -1113,13 +855,6 @@ setup_add_language_dialog (PrefsDialog *pd)
 				    COL_LANG_CODE, code,
 				    -1);
 		g_free (name);
-#else
-		gtk_list_store_append (store, &iter);
-		gtk_list_store_set (store, &iter,
-				    COL_LANG_NAME, _(languages[i].name),
-				    COL_LANG_CODE, languages[i].code,
-				    -1);
-#endif /* HAVE_ISO_CODES */
 	}
 
 	add_system_language_entry (store);
@@ -1289,10 +1024,8 @@ create_language_section (EphyDialog *dialog)
 	GtkTreeSelection *selection;
 	GSList *list, *l, *ulist = NULL;
 
-#ifdef HAVE_ISO_CODES
 	pd->priv->iso_639_table = ephy_langs_iso_639_table ();
 	pd->priv->iso_3166_table = ephy_langs_iso_3166_table ();
-#endif
 
 	ephy_dialog_get_controls
 		(dialog,
@@ -1320,7 +1053,7 @@ create_language_section (EphyDialog *dialog)
 	renderer = gtk_cell_renderer_text_new ();
 
 	gtk_tree_view_insert_column_with_attributes (treeview,
-						     0, "Language",
+						     0, _("Language"),
 						     renderer,
 						     "text", 0,
 						     NULL);
@@ -1360,7 +1093,6 @@ create_language_section (EphyDialog *dialog)
 	{
 		const char *code = (const char *) l->data;
 
-#ifdef HAVE_ISO_CODES
 		if (strcmp (code, "system") == 0)
 		{
 			add_system_language_entry (store);
@@ -1373,38 +1105,6 @@ create_language_section (EphyDialog *dialog)
 			language_editor_add (pd, code, text);
 			g_free (text);
 		}
-
-#else /* !HAVE_ISO_CODES */
-
-		int i, n_languages = G_N_ELEMENTS (languages);
-
-		for (i = 0; i < n_languages; i++)
-		{
-			if (strcmp (languages[i].code, code) == 0) break;
-		}
-
-		/* code isn't in stock list */
-		if (i == n_languages)
-		{
-			if (strcmp (code, "system") != 0)
-			{
-				char *text;
-	
-				text = g_strdup_printf (Q_("language|User defined (%s)"), code);
-	
-				language_editor_add (pd, code, text);
-				g_free (text);
-			}
-			else
-			{
-				add_system_language_entry (store);
-			}
-		}
-		else
-		{
-			language_editor_add (pd, code, _(languages[i].name));
-		}
-#endif /* HAVE_ISO_CODES */
 	}
 
 	language_editor_update_buttons (pd);
@@ -1438,7 +1138,7 @@ get_download_button_label (void)
 
 	if (key == NULL || g_utf8_collate (key, "~") == 0)
 	{
-		label = g_strdup (dgettext (GTK_DOMAIN, "Home"));
+		label = g_strdup (DGETTEXT_GTK_("Home"));
 	}
 	else if ((converted_dp != NULL && g_utf8_collate (key, converted_dp) == 0) ||
 		 g_utf8_collate (key, "Downloads") == 0)
@@ -1448,7 +1148,7 @@ get_download_button_label (void)
 	else if (g_utf8_collate (key, "~/Desktop") == 0 ||
 	         g_utf8_collate (key, "Desktop") == 0)
 	{
-		label = g_strdup (dgettext (GTK_DOMAIN, "Desktop"));
+		label = g_strdup (DGETTEXT_GTK_("Desktop"));
 	}
 	else
 	{
@@ -1499,7 +1199,7 @@ prefs_dialog_init (PrefsDialog *pd)
 			       NULL);
 
 	ephy_dialog_add_enum (dialog, properties[ACCEPT_COOKIES_PROP].id,
-			      n_cookies_accept_enum, cookies_accept_enum);
+			      G_N_ELEMENTS (cookies_accept_enum), cookies_accept_enum);
 
 	ephy_dialog_get_controls
 		(dialog,
@@ -1588,18 +1288,14 @@ void
 prefs_homepage_current_button_clicked_cb (GtkWidget *button,
 					  EphyDialog *dialog)
 {
-	EphySession *session;
-	EphyWindow *window;
+	GtkWidget *parent;
 	EphyEmbed *embed;
 	char *location;
 
-	session = EPHY_SESSION (ephy_shell_get_session (ephy_shell));
-	window = ephy_session_get_active_window (session);
+	parent = ephy_dialog_get_parent (dialog);
+	g_return_if_fail (parent != NULL);
 
-	/* can't do anything in this case */
-	if (window == NULL) return;
-
-	embed = ephy_window_get_active_embed (window);
+	embed = ephy_window_get_active_embed (EPHY_WINDOW (parent));
 	g_return_if_fail (embed != NULL);
 
 	location = ephy_embed_get_location (embed, TRUE);
