@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: window-commands.c,v 1.156 2005/02/27 20:13:26 chpe Exp $
+ *  $Id: window-commands.c,v 1.160 2005/05/28 21:58:47 chpe Exp $
  */
 
 #include "config.h"
@@ -44,6 +44,7 @@
 #include "ephy-zoom.h"
 #include "ephy-notebook.h"
 #include "ephy-toolbar-editor.h"
+#include "ephy-find-toolbar.h"
 
 #include <string.h>
 #include <glib.h>
@@ -72,7 +73,6 @@ window_cmd_file_print_setup (GtkAction *action,
 	EphyDialog *dialog;
 
 	dialog = EPHY_DIALOG (ephy_shell_get_print_setup_dialog (ephy_shell));
-	ephy_dialog_set_parent (dialog, GTK_WIDGET (window));
 
 	ephy_dialog_show (dialog);
 }
@@ -560,24 +560,20 @@ void
 window_cmd_edit_find_next (GtkAction *action,
 			   EphyWindow *window)
 {
-	EphyEmbed *embed;
+	EphyFindToolbar *toolbar;
 
-	embed = ephy_window_get_active_embed (window);
-	g_return_if_fail (embed != NULL);
-
-	ephy_embed_find_next (embed, FALSE);
+	toolbar = EPHY_FIND_TOOLBAR (ephy_window_get_find_toolbar (window));
+	ephy_find_toolbar_find_next (toolbar);
 }
 
 void
 window_cmd_edit_find_prev (GtkAction *action,
 			   EphyWindow *window)
 {
-	EphyEmbed *embed;
+	EphyFindToolbar *toolbar;
 
-	embed = ephy_window_get_active_embed (window);
-	g_return_if_fail (embed != NULL);
-
-	ephy_embed_find_next (embed, TRUE);
+	toolbar = EPHY_FIND_TOOLBAR (ephy_window_get_find_toolbar (window));
+	ephy_find_toolbar_find_previous (toolbar);
 }
 
 void
@@ -721,7 +717,6 @@ window_cmd_edit_personal_data (GtkAction *action,
 	EphyDialog *dialog;
 
 	dialog = EPHY_DIALOG (ephy_shell_get_pdm_dialog (ephy_shell));
-	ephy_dialog_set_parent (dialog, GTK_WIDGET (window));
 
 	ephy_dialog_show (dialog);
 }
@@ -733,7 +728,6 @@ window_cmd_edit_prefs (GtkAction *action,
 	EphyDialog *dialog;
 
 	dialog = EPHY_DIALOG (ephy_shell_get_prefs_dialog (ephy_shell));
-	ephy_dialog_set_parent (dialog, GTK_WIDGET (window));
 
 	ephy_dialog_show (dialog);
 }
@@ -756,15 +750,14 @@ void
 window_cmd_help_about (GtkAction *action,
 		       GtkWidget *window)
 {
-	static char *authors[] = {
+	static const char * const authors[] = {
 		"Marco Pesenti Gritti <marco@gnome.org>",
 		"Xan Lopez <xan@gnome.org>",
 		"David Bordoley <bordoley@msu.edu>",
 		"Christian Persch <chpe@gnome.org>",
 		NULL
 	};
-
-	static char *documenters[] = {
+	static const char *const documenters[] = {
 		"Patanjali Somayaji <patanjali@codito.com>",
 		"David Bordoley <bordoley@msu.edu>",
 		"Piers Cornwell <piers@gnome.org>", 
@@ -915,3 +908,25 @@ window_cmd_browse_with_caret (GtkAction *action,
 	active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
 	eel_gconf_set_boolean (CONF_BROWSE_WITH_CARET, active);
 }
+
+#ifdef HAVE_X11_XF86KEYSYM_H
+void
+window_cmd_go_home (GtkAction *action,
+		    EphyWindow *window)
+{
+	char *location;
+
+	location = eel_gconf_get_string (CONF_GENERAL_HOMEPAGE);
+
+	if (location == NULL || location[0] == '\0')
+	{
+		g_free (location);
+
+		location = g_strdup ("about:blank");
+	}
+
+	ephy_window_load_url (window, location);
+
+	g_free (location);
+}
+#endif /* HAVE_X11_XF86KEYSYM_H */
